"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import waE2E.WAWebProtobufsE2E_pb2
import waHistorySync.WAWebProtobufsHistorySync_pb2
import waSyncAction.WASyncAction_pb2
import waVnameCert.WAWebProtobufsVnameCert_pb2
import waWeb.WAWebProtobufsWeb_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NewsletterRole:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NewsletterRoleEnumTypeWrapper(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
        _NewsletterRole.ValueType
    ],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SUBSCRIBER: _NewsletterRole.ValueType  # 1
    GUEST: _NewsletterRole.ValueType  # 2
    ADMIN: _NewsletterRole.ValueType  # 3
    OWNER: _NewsletterRole.ValueType  # 4

class NewsletterRole(_NewsletterRole, metaclass=_NewsletterRoleEnumTypeWrapper): ...

SUBSCRIBER: NewsletterRole.ValueType  # 1
GUEST: NewsletterRole.ValueType  # 2
ADMIN: NewsletterRole.ValueType  # 3
OWNER: NewsletterRole.ValueType  # 4
global___NewsletterRole = NewsletterRole

class _NewsletterMuteState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NewsletterMuteStateEnumTypeWrapper(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
        _NewsletterMuteState.ValueType
    ],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ON: _NewsletterMuteState.ValueType  # 1
    OFF: _NewsletterMuteState.ValueType  # 2

class NewsletterMuteState(
    _NewsletterMuteState, metaclass=_NewsletterMuteStateEnumTypeWrapper
): ...

ON: NewsletterMuteState.ValueType  # 1
OFF: NewsletterMuteState.ValueType  # 2
global___NewsletterMuteState = NewsletterMuteState

class _ConnectFailureReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConnectFailureReasonEnumTypeWrapper(
    google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
        _ConnectFailureReason.ValueType
    ],
    builtins.type,
):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GENERIC: _ConnectFailureReason.ValueType  # 1
    LOGGED_OUT: _ConnectFailureReason.ValueType  # 2
    TEMP_BANNED: _ConnectFailureReason.ValueType  # 3
    MAIN_DEVICE_GONE: _ConnectFailureReason.ValueType  # 4
    UNKNOWN_LOGOUT: _ConnectFailureReason.ValueType  # 5
    CLIENT_OUTDATED: _ConnectFailureReason.ValueType  # 6
    BAD_USER_AGENT: _ConnectFailureReason.ValueType  # 7
    INTERNAL_SERVER_ERROR: _ConnectFailureReason.ValueType  # 8
    EXPERIMENTAL: _ConnectFailureReason.ValueType  # 9
    SERVICE_UNAVAILABLE: _ConnectFailureReason.ValueType  # 10

class ConnectFailureReason(
    _ConnectFailureReason, metaclass=_ConnectFailureReasonEnumTypeWrapper
): ...

GENERIC: ConnectFailureReason.ValueType  # 1
LOGGED_OUT: ConnectFailureReason.ValueType  # 2
TEMP_BANNED: ConnectFailureReason.ValueType  # 3
MAIN_DEVICE_GONE: ConnectFailureReason.ValueType  # 4
UNKNOWN_LOGOUT: ConnectFailureReason.ValueType  # 5
CLIENT_OUTDATED: ConnectFailureReason.ValueType  # 6
BAD_USER_AGENT: ConnectFailureReason.ValueType  # 7
INTERNAL_SERVER_ERROR: ConnectFailureReason.ValueType  # 8
EXPERIMENTAL: ConnectFailureReason.ValueType  # 9
SERVICE_UNAVAILABLE: ConnectFailureReason.ValueType  # 10
global___ConnectFailureReason = ConnectFailureReason

@typing.final
class JID(google.protobuf.message.Message):
    """types"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    RAWAGENT_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    INTEGRATOR_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    ISEMPTY_FIELD_NUMBER: builtins.int
    User: builtins.str
    RawAgent: builtins.int
    Device: builtins.int
    Integrator: builtins.int
    Server: builtins.str
    IsEmpty: builtins.bool
    def __init__(
        self,
        *,
        User: builtins.str | None = ...,
        RawAgent: builtins.int | None = ...,
        Device: builtins.int | None = ...,
        Integrator: builtins.int | None = ...,
        Server: builtins.str | None = ...,
        IsEmpty: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Device",
            b"Device",
            "Integrator",
            b"Integrator",
            "IsEmpty",
            b"IsEmpty",
            "RawAgent",
            b"RawAgent",
            "Server",
            b"Server",
            "User",
            b"User",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Device",
            b"Device",
            "Integrator",
            b"Integrator",
            "IsEmpty",
            b"IsEmpty",
            "RawAgent",
            b"RawAgent",
            "Server",
            b"Server",
            "User",
            b"User",
        ],
    ) -> None: ...

global___JID = JID

@typing.final
class MessageInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGESOURCE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SERVERID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    MULTICAST_FIELD_NUMBER: builtins.int
    MEDIATYPE_FIELD_NUMBER: builtins.int
    EDIT_FIELD_NUMBER: builtins.int
    VERIFIEDNAME_FIELD_NUMBER: builtins.int
    DEVICESENTMETA_FIELD_NUMBER: builtins.int
    ID: builtins.str
    ServerID: builtins.int
    Type: builtins.str
    Pushname: builtins.str
    Timestamp: builtins.int
    Category: builtins.str
    Multicast: builtins.bool
    MediaType: builtins.str
    Edit: builtins.str
    """enum"""
    @property
    def MessageSource(self) -> global___MessageSource: ...
    @property
    def VerifiedName(self) -> global___VerifiedName: ...
    @property
    def DeviceSentMeta(self) -> global___DeviceSentMeta: ...
    def __init__(
        self,
        *,
        MessageSource: global___MessageSource | None = ...,
        ID: builtins.str | None = ...,
        ServerID: builtins.int | None = ...,
        Type: builtins.str | None = ...,
        Pushname: builtins.str | None = ...,
        Timestamp: builtins.int | None = ...,
        Category: builtins.str | None = ...,
        Multicast: builtins.bool | None = ...,
        MediaType: builtins.str | None = ...,
        Edit: builtins.str | None = ...,
        VerifiedName: global___VerifiedName | None = ...,
        DeviceSentMeta: global___DeviceSentMeta | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Category",
            b"Category",
            "DeviceSentMeta",
            b"DeviceSentMeta",
            "Edit",
            b"Edit",
            "ID",
            b"ID",
            "MediaType",
            b"MediaType",
            "MessageSource",
            b"MessageSource",
            "Multicast",
            b"Multicast",
            "Pushname",
            b"Pushname",
            "ServerID",
            b"ServerID",
            "Timestamp",
            b"Timestamp",
            "Type",
            b"Type",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Category",
            b"Category",
            "DeviceSentMeta",
            b"DeviceSentMeta",
            "Edit",
            b"Edit",
            "ID",
            b"ID",
            "MediaType",
            b"MediaType",
            "MessageSource",
            b"MessageSource",
            "Multicast",
            b"Multicast",
            "Pushname",
            b"Pushname",
            "ServerID",
            b"ServerID",
            "Timestamp",
            b"Timestamp",
            "Type",
            b"Type",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> None: ...

global___MessageInfo = MessageInfo

@typing.final
class UploadResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    HANDLE_FIELD_NUMBER: builtins.int
    MEDIAKEY_FIELD_NUMBER: builtins.int
    FILEENCSHA256_FIELD_NUMBER: builtins.int
    FILESHA256_FIELD_NUMBER: builtins.int
    FILELENGTH_FIELD_NUMBER: builtins.int
    url: builtins.str
    DirectPath: builtins.str
    Handle: builtins.str
    MediaKey: builtins.bytes
    FileEncSHA256: builtins.bytes
    FileSHA256: builtins.bytes
    FileLength: builtins.int
    def __init__(
        self,
        *,
        url: builtins.str | None = ...,
        DirectPath: builtins.str | None = ...,
        Handle: builtins.str | None = ...,
        MediaKey: builtins.bytes | None = ...,
        FileEncSHA256: builtins.bytes | None = ...,
        FileSHA256: builtins.bytes | None = ...,
        FileLength: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DirectPath",
            b"DirectPath",
            "FileEncSHA256",
            b"FileEncSHA256",
            "FileLength",
            b"FileLength",
            "FileSHA256",
            b"FileSHA256",
            "Handle",
            b"Handle",
            "MediaKey",
            b"MediaKey",
            "url",
            b"url",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DirectPath",
            b"DirectPath",
            "FileEncSHA256",
            b"FileEncSHA256",
            "FileLength",
            b"FileLength",
            "FileSHA256",
            b"FileSHA256",
            "Handle",
            b"Handle",
            "MediaKey",
            b"MediaKey",
            "url",
            b"url",
        ],
    ) -> None: ...

global___UploadResponse = UploadResponse

@typing.final
class MessageSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    ISFROMME_FIELD_NUMBER: builtins.int
    ISGROUP_FIELD_NUMBER: builtins.int
    BROADCASTLISTOWNER_FIELD_NUMBER: builtins.int
    IsFromMe: builtins.bool
    IsGroup: builtins.bool
    @property
    def Chat(self) -> global___JID: ...
    @property
    def Sender(self) -> global___JID: ...
    @property
    def BroadcastListOwner(self) -> global___JID: ...
    def __init__(
        self,
        *,
        Chat: global___JID | None = ...,
        Sender: global___JID | None = ...,
        IsFromMe: builtins.bool | None = ...,
        IsGroup: builtins.bool | None = ...,
        BroadcastListOwner: global___JID | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "BroadcastListOwner",
            b"BroadcastListOwner",
            "Chat",
            b"Chat",
            "IsFromMe",
            b"IsFromMe",
            "IsGroup",
            b"IsGroup",
            "Sender",
            b"Sender",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "BroadcastListOwner",
            b"BroadcastListOwner",
            "Chat",
            b"Chat",
            "IsFromMe",
            b"IsFromMe",
            "IsGroup",
            b"IsGroup",
            "Sender",
            b"Sender",
        ],
    ) -> None: ...

global___MessageSource = MessageSource

@typing.final
class DeviceSentMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATIONJID_FIELD_NUMBER: builtins.int
    PHASH_FIELD_NUMBER: builtins.int
    DestinationJID: builtins.str
    Phash: builtins.str
    def __init__(
        self,
        *,
        DestinationJID: builtins.str | None = ...,
        Phash: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DestinationJID", b"DestinationJID", "Phash", b"Phash"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DestinationJID", b"DestinationJID", "Phash", b"Phash"
        ],
    ) -> None: ...

global___DeviceSentMeta = DeviceSentMeta

@typing.final
class VerifiedName(google.protobuf.message.Message):
    """}"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    @property
    def Certificate(
        self,
    ) -> waVnameCert.WAWebProtobufsVnameCert_pb2.VerifiedNameCertificate: ...
    @property
    def Details(
        self,
    ) -> waVnameCert.WAWebProtobufsVnameCert_pb2.VerifiedNameCertificate.Details: ...
    def __init__(
        self,
        *,
        Certificate: waVnameCert.WAWebProtobufsVnameCert_pb2.VerifiedNameCertificate
        | None = ...,
        Details: waVnameCert.WAWebProtobufsVnameCert_pb2.VerifiedNameCertificate.Details
        | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Certificate", b"Certificate", "Details", b"Details"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Certificate", b"Certificate", "Details", b"Details"
        ],
    ) -> None: ...

global___VerifiedName = VerifiedName

@typing.final
class IsOnWhatsAppResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    JID_FIELD_NUMBER: builtins.int
    ISIN_FIELD_NUMBER: builtins.int
    VERIFIEDNAME_FIELD_NUMBER: builtins.int
    Query: builtins.str
    IsIn: builtins.bool
    @property
    def JID(self) -> global___JID: ...
    @property
    def VerifiedName(self) -> global___VerifiedName: ...
    def __init__(
        self,
        *,
        Query: builtins.str | None = ...,
        JID: global___JID | None = ...,
        IsIn: builtins.bool | None = ...,
        VerifiedName: global___VerifiedName | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "IsIn",
            b"IsIn",
            "JID",
            b"JID",
            "Query",
            b"Query",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "IsIn",
            b"IsIn",
            "JID",
            b"JID",
            "Query",
            b"Query",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> None: ...

global___IsOnWhatsAppResponse = IsOnWhatsAppResponse

@typing.final
class UserInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERIFIEDNAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PICTUREID_FIELD_NUMBER: builtins.int
    DEVICES_FIELD_NUMBER: builtins.int
    Status: builtins.str
    PictureID: builtins.str
    @property
    def VerifiedName(self) -> global___VerifiedName: ...
    @property
    def Devices(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        VerifiedName: global___VerifiedName | None = ...,
        Status: builtins.str | None = ...,
        PictureID: builtins.str | None = ...,
        Devices: collections.abc.Iterable[global___JID] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "PictureID",
            b"PictureID",
            "Status",
            b"Status",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Devices",
            b"Devices",
            "PictureID",
            b"PictureID",
            "Status",
            b"Status",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> None: ...

global___UserInfo = UserInfo

@typing.final
class Device(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    BUSSINESSNAME_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    INITIALIZED_FIELD_NUMBER: builtins.int
    Platform: builtins.str
    BussinessName: builtins.str
    PushName: builtins.str
    Initialized: builtins.bool
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Platform: builtins.str | None = ...,
        BussinessName: builtins.str | None = ...,
        PushName: builtins.str | None = ...,
        Initialized: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "BussinessName",
            b"BussinessName",
            "Initialized",
            b"Initialized",
            "JID",
            b"JID",
            "Platform",
            b"Platform",
            "PushName",
            b"PushName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "BussinessName",
            b"BussinessName",
            "Initialized",
            b"Initialized",
            "JID",
            b"JID",
            "Platform",
            b"Platform",
            "PushName",
            b"PushName",
        ],
    ) -> None: ...

global___Device = Device

@typing.final
class GroupName(google.protobuf.message.Message):
    """GROUP"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESETAT_FIELD_NUMBER: builtins.int
    NAMESETBY_FIELD_NUMBER: builtins.int
    Name: builtins.str
    NameSetAt: builtins.int
    @property
    def NameSetBy(self) -> global___JID: ...
    def __init__(
        self,
        *,
        Name: builtins.str | None = ...,
        NameSetAt: builtins.int | None = ...,
        NameSetBy: global___JID | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Name", b"Name", "NameSetAt", b"NameSetAt", "NameSetBy", b"NameSetBy"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Name", b"Name", "NameSetAt", b"NameSetAt", "NameSetBy", b"NameSetBy"
        ],
    ) -> None: ...

global___GroupName = GroupName

@typing.final
class GroupTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    TOPICID_FIELD_NUMBER: builtins.int
    TOPICSETAT_FIELD_NUMBER: builtins.int
    TOPICSETBY_FIELD_NUMBER: builtins.int
    TOPICDELETED_FIELD_NUMBER: builtins.int
    Topic: builtins.str
    TopicID: builtins.str
    TopicSetAt: builtins.int
    TopicDeleted: builtins.bool
    @property
    def TopicSetBy(self) -> global___JID: ...
    def __init__(
        self,
        *,
        Topic: builtins.str | None = ...,
        TopicID: builtins.str | None = ...,
        TopicSetAt: builtins.int | None = ...,
        TopicSetBy: global___JID | None = ...,
        TopicDeleted: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Topic",
            b"Topic",
            "TopicDeleted",
            b"TopicDeleted",
            "TopicID",
            b"TopicID",
            "TopicSetAt",
            b"TopicSetAt",
            "TopicSetBy",
            b"TopicSetBy",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Topic",
            b"Topic",
            "TopicDeleted",
            b"TopicDeleted",
            "TopicID",
            b"TopicID",
            "TopicSetAt",
            b"TopicSetAt",
            "TopicSetBy",
            b"TopicSetBy",
        ],
    ) -> None: ...

global___GroupTopic = GroupTopic

@typing.final
class GroupLocked(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISLOCKED_FIELD_NUMBER: builtins.int
    isLocked: builtins.bool
    def __init__(
        self,
        *,
        isLocked: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["isLocked", b"isLocked"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["isLocked", b"isLocked"]
    ) -> None: ...

global___GroupLocked = GroupLocked

@typing.final
class GroupAnnounce(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISANNOUNCE_FIELD_NUMBER: builtins.int
    ANNOUNCEVERSIONID_FIELD_NUMBER: builtins.int
    IsAnnounce: builtins.bool
    AnnounceVersionID: builtins.str
    def __init__(
        self,
        *,
        IsAnnounce: builtins.bool | None = ...,
        AnnounceVersionID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "AnnounceVersionID", b"AnnounceVersionID", "IsAnnounce", b"IsAnnounce"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "AnnounceVersionID", b"AnnounceVersionID", "IsAnnounce", b"IsAnnounce"
        ],
    ) -> None: ...

global___GroupAnnounce = GroupAnnounce

@typing.final
class GroupEphemeral(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISEPHEMERAL_FIELD_NUMBER: builtins.int
    DISAPPEARINGTIMER_FIELD_NUMBER: builtins.int
    IsEphemeral: builtins.bool
    DisappearingTimer: builtins.int
    def __init__(
        self,
        *,
        IsEphemeral: builtins.bool | None = ...,
        DisappearingTimer: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DisappearingTimer", b"DisappearingTimer", "IsEphemeral", b"IsEphemeral"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DisappearingTimer", b"DisappearingTimer", "IsEphemeral", b"IsEphemeral"
        ],
    ) -> None: ...

global___GroupEphemeral = GroupEphemeral

@typing.final
class GroupIncognito(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISINCOGNITO_FIELD_NUMBER: builtins.int
    IsIncognito: builtins.bool
    def __init__(
        self,
        *,
        IsIncognito: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["IsIncognito", b"IsIncognito"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["IsIncognito", b"IsIncognito"]
    ) -> None: ...

global___GroupIncognito = GroupIncognito

@typing.final
class GroupParent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISPARENT_FIELD_NUMBER: builtins.int
    DEFAULTMEMBERSHIPAPPROVALMODE_FIELD_NUMBER: builtins.int
    IsParent: builtins.bool
    DefaultMembershipApprovalMode: builtins.str
    def __init__(
        self,
        *,
        IsParent: builtins.bool | None = ...,
        DefaultMembershipApprovalMode: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DefaultMembershipApprovalMode",
            b"DefaultMembershipApprovalMode",
            "IsParent",
            b"IsParent",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DefaultMembershipApprovalMode",
            b"DefaultMembershipApprovalMode",
            "IsParent",
            b"IsParent",
        ],
    ) -> None: ...

global___GroupParent = GroupParent

@typing.final
class GroupLinkedParent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINKEDPARENTJID_FIELD_NUMBER: builtins.int
    @property
    def LinkedParentJID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        LinkedParentJID: global___JID | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["LinkedParentJID", b"LinkedParentJID"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["LinkedParentJID", b"LinkedParentJID"]
    ) -> None: ...

global___GroupLinkedParent = GroupLinkedParent

@typing.final
class GroupIsDefaultSub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISDEFAULTSUBGROUP_FIELD_NUMBER: builtins.int
    IsDefaultSubGroup: builtins.bool
    def __init__(
        self,
        *,
        IsDefaultSubGroup: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["IsDefaultSubGroup", b"IsDefaultSubGroup"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["IsDefaultSubGroup", b"IsDefaultSubGroup"]
    ) -> None: ...

global___GroupIsDefaultSub = GroupIsDefaultSub

@typing.final
class GroupParticipantAddRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    Code: builtins.str
    Expiration: builtins.float
    def __init__(
        self,
        *,
        Code: builtins.str | None = ...,
        Expiration: builtins.float | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Code", b"Code", "Expiration", b"Expiration"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Code", b"Code", "Expiration", b"Expiration"]
    ) -> None: ...

global___GroupParticipantAddRequest = GroupParticipantAddRequest

@typing.final
class GroupParticipant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    LID_FIELD_NUMBER: builtins.int
    ISADMIN_FIELD_NUMBER: builtins.int
    ISSUPERADMIN_FIELD_NUMBER: builtins.int
    DISPLAYNAME_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    ADDREQUEST_FIELD_NUMBER: builtins.int
    IsAdmin: builtins.bool
    IsSuperAdmin: builtins.bool
    DisplayName: builtins.str
    Error: builtins.int
    @property
    def JID(self) -> global___JID: ...
    @property
    def LID(self) -> global___JID: ...
    @property
    def AddRequest(self) -> global___GroupParticipantAddRequest: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        LID: global___JID | None = ...,
        IsAdmin: builtins.bool | None = ...,
        IsSuperAdmin: builtins.bool | None = ...,
        DisplayName: builtins.str | None = ...,
        Error: builtins.int | None = ...,
        AddRequest: global___GroupParticipantAddRequest | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "AddRequest",
            b"AddRequest",
            "DisplayName",
            b"DisplayName",
            "Error",
            b"Error",
            "IsAdmin",
            b"IsAdmin",
            "IsSuperAdmin",
            b"IsSuperAdmin",
            "JID",
            b"JID",
            "LID",
            b"LID",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "AddRequest",
            b"AddRequest",
            "DisplayName",
            b"DisplayName",
            "Error",
            b"Error",
            "IsAdmin",
            b"IsAdmin",
            "IsSuperAdmin",
            b"IsSuperAdmin",
            "JID",
            b"JID",
            "LID",
            b"LID",
        ],
    ) -> None: ...

global___GroupParticipant = GroupParticipant

@typing.final
class GroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GroupMemberAddMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GroupMemberAddModeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GroupInfo._GroupMemberAddMode.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GroupMemberAddModeAdmin: GroupInfo._GroupMemberAddMode.ValueType  # 1

    class GroupMemberAddMode(
        _GroupMemberAddMode, metaclass=_GroupMemberAddModeEnumTypeWrapper
    ): ...
    GroupMemberAddModeAdmin: GroupInfo.GroupMemberAddMode.ValueType  # 1

    OWNERJID_FIELD_NUMBER: builtins.int
    JID_FIELD_NUMBER: builtins.int
    GROUPNAME_FIELD_NUMBER: builtins.int
    GROUPTOPIC_FIELD_NUMBER: builtins.int
    GROUPLOCKED_FIELD_NUMBER: builtins.int
    GROUPANNOUNCE_FIELD_NUMBER: builtins.int
    GROUPEPHEMERAL_FIELD_NUMBER: builtins.int
    GROUPINCOGNITO_FIELD_NUMBER: builtins.int
    GROUPPARENT_FIELD_NUMBER: builtins.int
    GROUPLINKEDPARENT_FIELD_NUMBER: builtins.int
    GROUPISDEFAULTSUB_FIELD_NUMBER: builtins.int
    GROUPCREATED_FIELD_NUMBER: builtins.int
    PARTICIPANTVERSIONID_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    GroupCreated: builtins.float
    ParticipantVersionID: builtins.str
    @property
    def OwnerJID(self) -> global___JID: ...
    @property
    def JID(self) -> global___JID: ...
    @property
    def GroupName(self) -> global___GroupName: ...
    @property
    def GroupTopic(self) -> global___GroupTopic: ...
    @property
    def GroupLocked(self) -> global___GroupLocked: ...
    @property
    def GroupAnnounce(self) -> global___GroupAnnounce: ...
    @property
    def GroupEphemeral(self) -> global___GroupEphemeral: ...
    @property
    def GroupIncognito(self) -> global___GroupIncognito: ...
    @property
    def GroupParent(self) -> global___GroupParent: ...
    @property
    def GroupLinkedParent(self) -> global___GroupLinkedParent: ...
    @property
    def GroupIsDefaultSub(self) -> global___GroupIsDefaultSub: ...
    @property
    def Participants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GroupParticipant
    ]: ...
    def __init__(
        self,
        *,
        OwnerJID: global___JID | None = ...,
        JID: global___JID | None = ...,
        GroupName: global___GroupName | None = ...,
        GroupTopic: global___GroupTopic | None = ...,
        GroupLocked: global___GroupLocked | None = ...,
        GroupAnnounce: global___GroupAnnounce | None = ...,
        GroupEphemeral: global___GroupEphemeral | None = ...,
        GroupIncognito: global___GroupIncognito | None = ...,
        GroupParent: global___GroupParent | None = ...,
        GroupLinkedParent: global___GroupLinkedParent | None = ...,
        GroupIsDefaultSub: global___GroupIsDefaultSub | None = ...,
        GroupCreated: builtins.float | None = ...,
        ParticipantVersionID: builtins.str | None = ...,
        Participants: collections.abc.Iterable[global___GroupParticipant] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "GroupAnnounce",
            b"GroupAnnounce",
            "GroupCreated",
            b"GroupCreated",
            "GroupEphemeral",
            b"GroupEphemeral",
            "GroupIncognito",
            b"GroupIncognito",
            "GroupIsDefaultSub",
            b"GroupIsDefaultSub",
            "GroupLinkedParent",
            b"GroupLinkedParent",
            "GroupLocked",
            b"GroupLocked",
            "GroupName",
            b"GroupName",
            "GroupParent",
            b"GroupParent",
            "GroupTopic",
            b"GroupTopic",
            "JID",
            b"JID",
            "OwnerJID",
            b"OwnerJID",
            "ParticipantVersionID",
            b"ParticipantVersionID",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "GroupAnnounce",
            b"GroupAnnounce",
            "GroupCreated",
            b"GroupCreated",
            "GroupEphemeral",
            b"GroupEphemeral",
            "GroupIncognito",
            b"GroupIncognito",
            "GroupIsDefaultSub",
            b"GroupIsDefaultSub",
            "GroupLinkedParent",
            b"GroupLinkedParent",
            "GroupLocked",
            b"GroupLocked",
            "GroupName",
            b"GroupName",
            "GroupParent",
            b"GroupParent",
            "GroupTopic",
            b"GroupTopic",
            "JID",
            b"JID",
            "OwnerJID",
            b"OwnerJID",
            "ParticipantVersionID",
            b"ParticipantVersionID",
            "Participants",
            b"Participants",
        ],
    ) -> None: ...

global___GroupInfo = GroupInfo

@typing.final
class MessageDebugTimings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_FIELD_NUMBER: builtins.int
    MARSHAL_FIELD_NUMBER: builtins.int
    GETPARTICIPANTS_FIELD_NUMBER: builtins.int
    GETDEVICES_FIELD_NUMBER: builtins.int
    GROUPENCRYPT_FIELD_NUMBER: builtins.int
    PEERENCRYPT_FIELD_NUMBER: builtins.int
    SEND_FIELD_NUMBER: builtins.int
    RESP_FIELD_NUMBER: builtins.int
    RETRY_FIELD_NUMBER: builtins.int
    Queue: builtins.int
    Marshal: builtins.int
    GetParticipants: builtins.int
    GetDevices: builtins.int
    GroupEncrypt: builtins.int
    PeerEncrypt: builtins.int
    Send: builtins.int
    Resp: builtins.int
    Retry: builtins.int
    def __init__(
        self,
        *,
        Queue: builtins.int | None = ...,
        Marshal: builtins.int | None = ...,
        GetParticipants: builtins.int | None = ...,
        GetDevices: builtins.int | None = ...,
        GroupEncrypt: builtins.int | None = ...,
        PeerEncrypt: builtins.int | None = ...,
        Send: builtins.int | None = ...,
        Resp: builtins.int | None = ...,
        Retry: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "GetDevices",
            b"GetDevices",
            "GetParticipants",
            b"GetParticipants",
            "GroupEncrypt",
            b"GroupEncrypt",
            "Marshal",
            b"Marshal",
            "PeerEncrypt",
            b"PeerEncrypt",
            "Queue",
            b"Queue",
            "Resp",
            b"Resp",
            "Retry",
            b"Retry",
            "Send",
            b"Send",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "GetDevices",
            b"GetDevices",
            "GetParticipants",
            b"GetParticipants",
            "GroupEncrypt",
            b"GroupEncrypt",
            "Marshal",
            b"Marshal",
            "PeerEncrypt",
            b"PeerEncrypt",
            "Queue",
            b"Queue",
            "Resp",
            b"Resp",
            "Retry",
            b"Retry",
            "Send",
            b"Send",
        ],
    ) -> None: ...

global___MessageDebugTimings = MessageDebugTimings

@typing.final
class SendResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    SERVERID_FIELD_NUMBER: builtins.int
    DEBUGTIMINGS_FIELD_NUMBER: builtins.int
    Timestamp: builtins.int
    ID: builtins.str
    ServerID: builtins.int
    @property
    def DebugTimings(self) -> global___MessageDebugTimings: ...
    def __init__(
        self,
        *,
        Timestamp: builtins.int | None = ...,
        ID: builtins.str | None = ...,
        ServerID: builtins.int | None = ...,
        DebugTimings: global___MessageDebugTimings | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DebugTimings",
            b"DebugTimings",
            "ID",
            b"ID",
            "ServerID",
            b"ServerID",
            "Timestamp",
            b"Timestamp",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DebugTimings",
            b"DebugTimings",
            "ID",
            b"ID",
            "ServerID",
            b"ServerID",
            "Timestamp",
            b"Timestamp",
        ],
    ) -> None: ...

global___SendResponse = SendResponse

@typing.final
class SendMessageReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    SENDRESPONSE_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def SendResponse(self) -> global___SendResponse: ...
    def __init__(
        self,
        *,
        Error: builtins.str | None = ...,
        SendResponse: global___SendResponse | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["Error", b"Error", "SendResponse", b"SendResponse"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["Error", b"Error", "SendResponse", b"SendResponse"],
    ) -> None: ...

global___SendMessageReturnFunction = SendMessageReturnFunction

@typing.final
class GetGroupInfoReturnFunction(google.protobuf.message.Message):
    """Function"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPINFO_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def GroupInfo(self) -> global___GroupInfo: ...
    def __init__(
        self,
        *,
        GroupInfo: global___GroupInfo | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "GroupInfo", b"GroupInfo"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "GroupInfo", b"GroupInfo"]
    ) -> None: ...

global___GetGroupInfoReturnFunction = GetGroupInfoReturnFunction

@typing.final
class JoinGroupWithLinkReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    JID_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Jid(self) -> global___JID: ...
    def __init__(
        self,
        *,
        Error: builtins.str | None = ...,
        Jid: global___JID | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "Jid", b"Jid"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "Jid", b"Jid"]
    ) -> None: ...

global___JoinGroupWithLinkReturnFunction = JoinGroupWithLinkReturnFunction

@typing.final
class GetGroupInviteLinkReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITELINK_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    InviteLink: builtins.str
    Error: builtins.str
    def __init__(
        self,
        *,
        InviteLink: builtins.str | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "InviteLink", b"InviteLink"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "InviteLink", b"InviteLink"]
    ) -> None: ...

global___GetGroupInviteLinkReturnFunction = GetGroupInviteLinkReturnFunction

@typing.final
class DownloadReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINARY_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Binary: builtins.bytes
    Error: builtins.str
    def __init__(
        self,
        *,
        Binary: builtins.bytes | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Binary", b"Binary", "Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Binary", b"Binary", "Error", b"Error"]
    ) -> None: ...

global___DownloadReturnFunction = DownloadReturnFunction

@typing.final
class UploadReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOADRESPONSE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def UploadResponse(self) -> global___UploadResponse: ...
    def __init__(
        self,
        *,
        UploadResponse: global___UploadResponse | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "UploadResponse", b"UploadResponse"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "UploadResponse", b"UploadResponse"
        ],
    ) -> None: ...

global___UploadReturnFunction = UploadReturnFunction

@typing.final
class SetGroupPhotoReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PICTUREID_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    PictureID: builtins.str
    Error: builtins.str
    def __init__(
        self,
        *,
        PictureID: builtins.str | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "PictureID", b"PictureID"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "PictureID", b"PictureID"]
    ) -> None: ...

global___SetGroupPhotoReturnFunction = SetGroupPhotoReturnFunction

@typing.final
class IsOnWhatsAppReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISONWHATSAPPRESPONSE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def IsOnWhatsAppResponse(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___IsOnWhatsAppResponse
    ]: ...
    def __init__(
        self,
        *,
        IsOnWhatsAppResponse: collections.abc.Iterable[global___IsOnWhatsAppResponse]
        | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "IsOnWhatsAppResponse", b"IsOnWhatsAppResponse"
        ],
    ) -> None: ...

global___IsOnWhatsAppReturnFunction = IsOnWhatsAppReturnFunction

@typing.final
class GetUserInfoSingleReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    USERINFO_FIELD_NUMBER: builtins.int
    @property
    def JID(self) -> global___JID: ...
    @property
    def UserInfo(self) -> global___UserInfo: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        UserInfo: global___UserInfo | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["JID", b"JID", "UserInfo", b"UserInfo"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["JID", b"JID", "UserInfo", b"UserInfo"]
    ) -> None: ...

global___GetUserInfoSingleReturnFunction = GetUserInfoSingleReturnFunction

@typing.final
class GetUserInfoReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERSINFO_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def UsersInfo(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GetUserInfoSingleReturnFunction
    ]: ...
    def __init__(
        self,
        *,
        UsersInfo: collections.abc.Iterable[global___GetUserInfoSingleReturnFunction]
        | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "UsersInfo", b"UsersInfo"]
    ) -> None: ...

global___GetUserInfoReturnFunction = GetUserInfoReturnFunction

@typing.final
class BuildPollVoteReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLLVOTE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def PollVote(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    def __init__(
        self,
        *,
        PollVote: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "PollVote", b"PollVote"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "PollVote", b"PollVote"]
    ) -> None: ...

global___BuildPollVoteReturnFunction = BuildPollVoteReturnFunction

@typing.final
class CreateNewsLetterReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWSLETTERMETADATA_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def NewsletterMetadata(self) -> global___NewsletterMetadata: ...
    def __init__(
        self,
        *,
        NewsletterMetadata: global___NewsletterMetadata | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "NewsletterMetadata", b"NewsletterMetadata"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "NewsletterMetadata", b"NewsletterMetadata"
        ],
    ) -> None: ...

global___CreateNewsLetterReturnFunction = CreateNewsLetterReturnFunction

@typing.final
class GetBlocklistReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCKLIST_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Blocklist(self) -> global___Blocklist: ...
    def __init__(
        self,
        *,
        Blocklist: global___Blocklist | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Blocklist", b"Blocklist", "Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Blocklist", b"Blocklist", "Error", b"Error"]
    ) -> None: ...

global___GetBlocklistReturnFunction = GetBlocklistReturnFunction

@typing.final
class GetContactQRLinkReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LINK_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Link: builtins.str
    Error: builtins.str
    def __init__(
        self,
        *,
        Link: builtins.str | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "Link", b"Link"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "Link", b"Link"]
    ) -> None: ...

global___GetContactQRLinkReturnFunction = GetContactQRLinkReturnFunction

@typing.final
class GetGroupRequestParticipantsReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTICIPANTS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Participants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        Participants: collections.abc.Iterable[global___JID] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["Error", b"Error", "Participants", b"Participants"],
    ) -> None: ...

global___GetGroupRequestParticipantsReturnFunction = (
    GetGroupRequestParticipantsReturnFunction
)

@typing.final
class GetJoinedGroupsReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Group(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GroupInfo
    ]: ...
    def __init__(
        self,
        *,
        Group: collections.abc.Iterable[global___GroupInfo] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "Group", b"Group"]
    ) -> None: ...

global___GetJoinedGroupsReturnFunction = GetJoinedGroupsReturnFunction

@typing.final
class ReqCreateGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    CREATEKEY_FIELD_NUMBER: builtins.int
    GROUPPARENT_FIELD_NUMBER: builtins.int
    GROUPLINKEDPARENT_FIELD_NUMBER: builtins.int
    name: builtins.str
    CreateKey: builtins.str
    @property
    def Participants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    @property
    def GroupParent(self) -> global___GroupParent: ...
    @property
    def GroupLinkedParent(self) -> global___GroupLinkedParent: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        Participants: collections.abc.Iterable[global___JID] | None = ...,
        CreateKey: builtins.str | None = ...,
        GroupParent: global___GroupParent | None = ...,
        GroupLinkedParent: global___GroupLinkedParent | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "CreateKey",
            b"CreateKey",
            "GroupLinkedParent",
            b"GroupLinkedParent",
            "GroupParent",
            b"GroupParent",
            "name",
            b"name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "CreateKey",
            b"CreateKey",
            "GroupLinkedParent",
            b"GroupLinkedParent",
            "GroupParent",
            b"GroupParent",
            "Participants",
            b"Participants",
            "name",
            b"name",
        ],
    ) -> None: ...

global___ReqCreateGroup = ReqCreateGroup

@typing.final
class JIDArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JIDS_FIELD_NUMBER: builtins.int
    @property
    def JIDS(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        JIDS: collections.abc.Iterable[global___JID] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["JIDS", b"JIDS"]) -> None: ...

global___JIDArray = JIDArray

@typing.final
class ArrayString(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(
        self,
    ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.str
    ]: ...
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data", b"data"]) -> None: ...

global___ArrayString = ArrayString

@typing.final
class NewsLetterMessageMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EDITTS_FIELD_NUMBER: builtins.int
    ORIGINALTS_FIELD_NUMBER: builtins.int
    EditTS: builtins.int
    OriginalTS: builtins.int
    def __init__(
        self,
        *,
        EditTS: builtins.int | None = ...,
        OriginalTS: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["EditTS", b"EditTS", "OriginalTS", b"OriginalTS"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["EditTS", b"EditTS", "OriginalTS", b"OriginalTS"],
    ) -> None: ...

global___NewsLetterMessageMeta = NewsLetterMessageMeta

@typing.final
class GroupDelete(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_FIELD_NUMBER: builtins.int
    DELETEDREASON_FIELD_NUMBER: builtins.int
    Deleted: builtins.bool
    DeletedReason: builtins.str
    def __init__(
        self,
        *,
        Deleted: builtins.bool | None = ...,
        DeletedReason: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Deleted", b"Deleted", "DeletedReason", b"DeletedReason"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Deleted", b"Deleted", "DeletedReason", b"DeletedReason"
        ],
    ) -> None: ...

global___GroupDelete = GroupDelete

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    ISEPHEMERAL_FIELD_NUMBER: builtins.int
    ISVIEWONCE_FIELD_NUMBER: builtins.int
    ISVIEWONCEV2_FIELD_NUMBER: builtins.int
    ISVIEWONCEV2EXTENSION_FIELD_NUMBER: builtins.int
    ISDOCUMENTWITHCAPTION_FIELD_NUMBER: builtins.int
    ISLOTTIESTICKER_FIELD_NUMBER: builtins.int
    ISEDIT_FIELD_NUMBER: builtins.int
    SOURCEWEBMSG_FIELD_NUMBER: builtins.int
    UNAVAILABLEREQUESTID_FIELD_NUMBER: builtins.int
    RETRYCOUNT_FIELD_NUMBER: builtins.int
    NEWSLETTERMETA_FIELD_NUMBER: builtins.int
    IsEphemeral: builtins.bool
    IsViewOnce: builtins.bool
    IsViewOnceV2: builtins.bool
    IsViewOnceV2Extension: builtins.bool
    IsDocumentWithCaption: builtins.bool
    IsLottieSticker: builtins.bool
    IsEdit: builtins.bool
    UnavailableRequestID: builtins.str
    RetryCount: builtins.int
    @property
    def Info(self) -> global___MessageInfo: ...
    @property
    def Message(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    @property
    def SourceWebMsg(self) -> waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo: ...
    @property
    def NewsLetterMeta(self) -> global___NewsLetterMessageMeta: ...
    def __init__(
        self,
        *,
        Info: global___MessageInfo | None = ...,
        Message: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
        IsEphemeral: builtins.bool | None = ...,
        IsViewOnce: builtins.bool | None = ...,
        IsViewOnceV2: builtins.bool | None = ...,
        IsViewOnceV2Extension: builtins.bool | None = ...,
        IsDocumentWithCaption: builtins.bool | None = ...,
        IsLottieSticker: builtins.bool | None = ...,
        IsEdit: builtins.bool | None = ...,
        SourceWebMsg: waWeb.WAWebProtobufsWeb_pb2.WebMessageInfo | None = ...,
        UnavailableRequestID: builtins.str | None = ...,
        RetryCount: builtins.int | None = ...,
        NewsLetterMeta: global___NewsLetterMessageMeta | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Info",
            b"Info",
            "IsDocumentWithCaption",
            b"IsDocumentWithCaption",
            "IsEdit",
            b"IsEdit",
            "IsEphemeral",
            b"IsEphemeral",
            "IsLottieSticker",
            b"IsLottieSticker",
            "IsViewOnce",
            b"IsViewOnce",
            "IsViewOnceV2",
            b"IsViewOnceV2",
            "IsViewOnceV2Extension",
            b"IsViewOnceV2Extension",
            "Message",
            b"Message",
            "NewsLetterMeta",
            b"NewsLetterMeta",
            "RetryCount",
            b"RetryCount",
            "SourceWebMsg",
            b"SourceWebMsg",
            "UnavailableRequestID",
            b"UnavailableRequestID",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Info",
            b"Info",
            "IsDocumentWithCaption",
            b"IsDocumentWithCaption",
            "IsEdit",
            b"IsEdit",
            "IsEphemeral",
            b"IsEphemeral",
            "IsLottieSticker",
            b"IsLottieSticker",
            "IsViewOnce",
            b"IsViewOnce",
            "IsViewOnceV2",
            b"IsViewOnceV2",
            "IsViewOnceV2Extension",
            b"IsViewOnceV2Extension",
            "Message",
            b"Message",
            "NewsLetterMeta",
            b"NewsLetterMeta",
            "RetryCount",
            b"RetryCount",
            "SourceWebMsg",
            b"SourceWebMsg",
            "UnavailableRequestID",
            b"UnavailableRequestID",
        ],
    ) -> None: ...

global___Message = Message

@typing.final
class CreateNewsletterParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    Name: builtins.str
    Description: builtins.str
    Picture: builtins.bytes
    def __init__(
        self,
        *,
        Name: builtins.str | None = ...,
        Description: builtins.str | None = ...,
        Picture: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Description", b"Description", "Name", b"Name", "Picture", b"Picture"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Description", b"Description", "Name", b"Name", "Picture", b"Picture"
        ],
    ) -> None: ...

global___CreateNewsletterParams = CreateNewsletterParams

@typing.final
class WrappedNewsletterState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _NewsletterState:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NewsletterStateEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            WrappedNewsletterState._NewsletterState.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTIVE: WrappedNewsletterState._NewsletterState.ValueType  # 1
        SUSPENDED: WrappedNewsletterState._NewsletterState.ValueType  # 2
        GEOSUSPENDED: WrappedNewsletterState._NewsletterState.ValueType  # 3

    class NewsletterState(
        _NewsletterState, metaclass=_NewsletterStateEnumTypeWrapper
    ): ...
    ACTIVE: WrappedNewsletterState.NewsletterState.ValueType  # 1
    SUSPENDED: WrappedNewsletterState.NewsletterState.ValueType  # 2
    GEOSUSPENDED: WrappedNewsletterState.NewsletterState.ValueType  # 3

    TYPE_FIELD_NUMBER: builtins.int
    Type: global___WrappedNewsletterState.NewsletterState.ValueType
    def __init__(
        self,
        *,
        Type: global___WrappedNewsletterState.NewsletterState.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Type", b"Type"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Type", b"Type"]) -> None: ...

global___WrappedNewsletterState = WrappedNewsletterState

@typing.final
class NewsletterText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    UPDATETIME_FIELD_NUMBER: builtins.int
    Text: builtins.str
    ID: builtins.str
    UpdateTime: builtins.int
    def __init__(
        self,
        *,
        Text: builtins.str | None = ...,
        ID: builtins.str | None = ...,
        UpdateTime: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ID", b"ID", "Text", b"Text", "UpdateTime", b"UpdateTime"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ID", b"ID", "Text", b"Text", "UpdateTime", b"UpdateTime"
        ],
    ) -> None: ...

global___NewsletterText = NewsletterText

@typing.final
class ProfilePictureInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DIRECTPATH_FIELD_NUMBER: builtins.int
    URL: builtins.str
    ID: builtins.str
    Type: builtins.str
    DirectPath: builtins.str
    def __init__(
        self,
        *,
        URL: builtins.str | None = ...,
        ID: builtins.str | None = ...,
        Type: builtins.str | None = ...,
        DirectPath: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "DirectPath", b"DirectPath", "ID", b"ID", "Type", b"Type", "URL", b"URL"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "DirectPath", b"DirectPath", "ID", b"ID", "Type", b"Type", "URL", b"URL"
        ],
    ) -> None: ...

global___ProfilePictureInfo = ProfilePictureInfo

@typing.final
class NewsletterReactionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _NewsletterReactionsMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NewsletterReactionsModeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NewsletterReactionSettings._NewsletterReactionsMode.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALL: NewsletterReactionSettings._NewsletterReactionsMode.ValueType  # 1
        BASIC: NewsletterReactionSettings._NewsletterReactionsMode.ValueType  # 2
        NONE: NewsletterReactionSettings._NewsletterReactionsMode.ValueType  # 3
        BLOCKLIST: NewsletterReactionSettings._NewsletterReactionsMode.ValueType  # 4

    class NewsletterReactionsMode(
        _NewsletterReactionsMode, metaclass=_NewsletterReactionsModeEnumTypeWrapper
    ): ...
    ALL: NewsletterReactionSettings.NewsletterReactionsMode.ValueType  # 1
    BASIC: NewsletterReactionSettings.NewsletterReactionsMode.ValueType  # 2
    NONE: NewsletterReactionSettings.NewsletterReactionsMode.ValueType  # 3
    BLOCKLIST: NewsletterReactionSettings.NewsletterReactionsMode.ValueType  # 4

    VALUE_FIELD_NUMBER: builtins.int
    Value: global___NewsletterReactionSettings.NewsletterReactionsMode.ValueType
    def __init__(
        self,
        *,
        Value: global___NewsletterReactionSettings.NewsletterReactionsMode.ValueType
        | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Value", b"Value"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Value", b"Value"]) -> None: ...

global___NewsletterReactionSettings = NewsletterReactionSettings

@typing.final
class NewsletterSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REACTIONCODES_FIELD_NUMBER: builtins.int
    @property
    def ReactionCodes(self) -> global___NewsletterReactionSettings: ...
    def __init__(
        self,
        *,
        ReactionCodes: global___NewsletterReactionSettings | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["ReactionCodes", b"ReactionCodes"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["ReactionCodes", b"ReactionCodes"]
    ) -> None: ...

global___NewsletterSetting = NewsletterSetting

@typing.final
class NewsletterThreadMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _NewsletterVerificationState:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NewsletterVerificationStateEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            NewsletterThreadMetadata._NewsletterVerificationState.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VERIFIED: NewsletterThreadMetadata._NewsletterVerificationState.ValueType  # 1
        UNVERIFIED: NewsletterThreadMetadata._NewsletterVerificationState.ValueType  # 2

    class NewsletterVerificationState(
        _NewsletterVerificationState,
        metaclass=_NewsletterVerificationStateEnumTypeWrapper,
    ): ...
    VERIFIED: NewsletterThreadMetadata.NewsletterVerificationState.ValueType  # 1
    UNVERIFIED: NewsletterThreadMetadata.NewsletterVerificationState.ValueType  # 2

    CREATIONTIME_FIELD_NUMBER: builtins.int
    INVITECODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUBSCRIBERCOUNT_FIELD_NUMBER: builtins.int
    VERIFICATIONSTATE_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    CreationTime: builtins.int
    InviteCode: builtins.str
    SubscriberCount: builtins.int
    VerificationState: (
        global___NewsletterThreadMetadata.NewsletterVerificationState.ValueType
    )
    @property
    def Name(self) -> global___NewsletterText: ...
    @property
    def Description(self) -> global___NewsletterText: ...
    @property
    def Picture(self) -> global___ProfilePictureInfo: ...
    @property
    def Preview(self) -> global___ProfilePictureInfo: ...
    @property
    def Settings(self) -> global___NewsletterSetting: ...
    def __init__(
        self,
        *,
        CreationTime: builtins.int | None = ...,
        InviteCode: builtins.str | None = ...,
        Name: global___NewsletterText | None = ...,
        Description: global___NewsletterText | None = ...,
        SubscriberCount: builtins.int | None = ...,
        VerificationState: global___NewsletterThreadMetadata.NewsletterVerificationState.ValueType
        | None = ...,
        Picture: global___ProfilePictureInfo | None = ...,
        Preview: global___ProfilePictureInfo | None = ...,
        Settings: global___NewsletterSetting | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "CreationTime",
            b"CreationTime",
            "Description",
            b"Description",
            "InviteCode",
            b"InviteCode",
            "Name",
            b"Name",
            "Picture",
            b"Picture",
            "Preview",
            b"Preview",
            "Settings",
            b"Settings",
            "SubscriberCount",
            b"SubscriberCount",
            "VerificationState",
            b"VerificationState",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "CreationTime",
            b"CreationTime",
            "Description",
            b"Description",
            "InviteCode",
            b"InviteCode",
            "Name",
            b"Name",
            "Picture",
            b"Picture",
            "Preview",
            b"Preview",
            "Settings",
            b"Settings",
            "SubscriberCount",
            b"SubscriberCount",
            "VerificationState",
            b"VerificationState",
        ],
    ) -> None: ...

global___NewsletterThreadMetadata = NewsletterThreadMetadata

@typing.final
class NewsletterViewerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    Mute: global___NewsletterMuteState.ValueType
    Role: global___NewsletterRole.ValueType
    def __init__(
        self,
        *,
        Mute: global___NewsletterMuteState.ValueType | None = ...,
        Role: global___NewsletterRole.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Mute", b"Mute", "Role", b"Role"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Mute", b"Mute", "Role", b"Role"]
    ) -> None: ...

global___NewsletterViewerMetadata = NewsletterViewerMetadata

@typing.final
class NewsletterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    THREADMETA_FIELD_NUMBER: builtins.int
    VIEWERMETA_FIELD_NUMBER: builtins.int
    @property
    def ID(self) -> global___JID: ...
    @property
    def State(self) -> global___WrappedNewsletterState: ...
    @property
    def ThreadMeta(self) -> global___NewsletterThreadMetadata: ...
    @property
    def ViewerMeta(self) -> global___NewsletterViewerMetadata: ...
    def __init__(
        self,
        *,
        ID: global___JID | None = ...,
        State: global___WrappedNewsletterState | None = ...,
        ThreadMeta: global___NewsletterThreadMetadata | None = ...,
        ViewerMeta: global___NewsletterViewerMetadata | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ID",
            b"ID",
            "State",
            b"State",
            "ThreadMeta",
            b"ThreadMeta",
            "ViewerMeta",
            b"ViewerMeta",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ID",
            b"ID",
            "State",
            b"State",
            "ThreadMeta",
            b"ThreadMeta",
            "ViewerMeta",
            b"ViewerMeta",
        ],
    ) -> None: ...

global___NewsletterMetadata = NewsletterMetadata

@typing.final
class Blocklist(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DHASH_FIELD_NUMBER: builtins.int
    JIDS_FIELD_NUMBER: builtins.int
    DHash: builtins.str
    @property
    def JIDs(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        DHash: builtins.str | None = ...,
        JIDs: collections.abc.Iterable[global___JID] | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["DHash", b"DHash"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["DHash", b"DHash", "JIDs", b"JIDs"]
    ) -> None: ...

global___Blocklist = Blocklist

@typing.final
class Reaction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    type: builtins.str
    count: builtins.int
    def __init__(
        self,
        *,
        type: builtins.str | None = ...,
        count: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["count", b"count", "type", b"type"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["count", b"count", "type", b"type"]
    ) -> None: ...

global___Reaction = Reaction

@typing.final
class NewsletterMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGESERVERID_FIELD_NUMBER: builtins.int
    VIEWSCOUNT_FIELD_NUMBER: builtins.int
    REACTIONCOUNTS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    MessageServerID: builtins.int
    ViewsCount: builtins.int
    @property
    def ReactionCounts(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Reaction
    ]: ...
    @property
    def Message(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    def __init__(
        self,
        *,
        MessageServerID: builtins.int | None = ...,
        ViewsCount: builtins.int | None = ...,
        ReactionCounts: collections.abc.Iterable[global___Reaction] | None = ...,
        Message: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Message",
            b"Message",
            "MessageServerID",
            b"MessageServerID",
            "ViewsCount",
            b"ViewsCount",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Message",
            b"Message",
            "MessageServerID",
            b"MessageServerID",
            "ReactionCounts",
            b"ReactionCounts",
            "ViewsCount",
            b"ViewsCount",
        ],
    ) -> None: ...

global___NewsletterMessage = NewsletterMessage

@typing.final
class GetNewsletterMessageUpdateReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWSLETTERMESSAGE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def NewsletterMessage(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___NewsletterMessage
    ]: ...
    def __init__(
        self,
        *,
        NewsletterMessage: collections.abc.Iterable[global___NewsletterMessage]
        | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "NewsletterMessage", b"NewsletterMessage"
        ],
    ) -> None: ...

global___GetNewsletterMessageUpdateReturnFunction = (
    GetNewsletterMessageUpdateReturnFunction
)

@typing.final
class PrivacySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PrivacySetting:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivacySettingEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PrivacySettings._PrivacySetting.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNDEFINED: PrivacySettings._PrivacySetting.ValueType  # 1
        ALL: PrivacySettings._PrivacySetting.ValueType  # 2
        CONTACTS: PrivacySettings._PrivacySetting.ValueType  # 3
        CONTACT_BLACKLIST: PrivacySettings._PrivacySetting.ValueType  # 4
        MATCH_LAST_SEEN: PrivacySettings._PrivacySetting.ValueType  # 5
        KNOWN: PrivacySettings._PrivacySetting.ValueType  # 6
        NONE: PrivacySettings._PrivacySetting.ValueType  # 7

    class PrivacySetting(_PrivacySetting, metaclass=_PrivacySettingEnumTypeWrapper): ...
    UNDEFINED: PrivacySettings.PrivacySetting.ValueType  # 1
    ALL: PrivacySettings.PrivacySetting.ValueType  # 2
    CONTACTS: PrivacySettings.PrivacySetting.ValueType  # 3
    CONTACT_BLACKLIST: PrivacySettings.PrivacySetting.ValueType  # 4
    MATCH_LAST_SEEN: PrivacySettings.PrivacySetting.ValueType  # 5
    KNOWN: PrivacySettings.PrivacySetting.ValueType  # 6
    NONE: PrivacySettings.PrivacySetting.ValueType  # 7

    GROUPADD_FIELD_NUMBER: builtins.int
    LASTSEEN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    READRECEIPTS_FIELD_NUMBER: builtins.int
    CALLADD_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    GroupAdd: global___PrivacySettings.PrivacySetting.ValueType
    LastSeen: global___PrivacySettings.PrivacySetting.ValueType
    Status: global___PrivacySettings.PrivacySetting.ValueType
    Profile: global___PrivacySettings.PrivacySetting.ValueType
    ReadReceipts: global___PrivacySettings.PrivacySetting.ValueType
    CallAdd: global___PrivacySettings.PrivacySetting.ValueType
    Online: global___PrivacySettings.PrivacySetting.ValueType
    def __init__(
        self,
        *,
        GroupAdd: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        LastSeen: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        Status: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        Profile: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        ReadReceipts: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        CallAdd: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
        Online: global___PrivacySettings.PrivacySetting.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "CallAdd",
            b"CallAdd",
            "GroupAdd",
            b"GroupAdd",
            "LastSeen",
            b"LastSeen",
            "Online",
            b"Online",
            "Profile",
            b"Profile",
            "ReadReceipts",
            b"ReadReceipts",
            "Status",
            b"Status",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "CallAdd",
            b"CallAdd",
            "GroupAdd",
            b"GroupAdd",
            "LastSeen",
            b"LastSeen",
            "Online",
            b"Online",
            "Profile",
            b"Profile",
            "ReadReceipts",
            b"ReadReceipts",
            "Status",
            b"Status",
        ],
    ) -> None: ...

global___PrivacySettings = PrivacySettings

@typing.final
class NodeAttrs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BOOLEAN_FIELD_NUMBER: builtins.int
    INTEGER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    JID_FIELD_NUMBER: builtins.int
    name: builtins.str
    boolean: builtins.bool
    integer: builtins.int
    text: builtins.str
    @property
    def jid(self) -> global___JID: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        boolean: builtins.bool | None = ...,
        integer: builtins.int | None = ...,
        text: builtins.str | None = ...,
        jid: global___JID | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Value",
            b"Value",
            "boolean",
            b"boolean",
            "integer",
            b"integer",
            "jid",
            b"jid",
            "name",
            b"name",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Value",
            b"Value",
            "boolean",
            b"boolean",
            "integer",
            b"integer",
            "jid",
            b"jid",
            "name",
            b"name",
            "text",
            b"text",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing.Literal["Value", b"Value"]
    ) -> typing.Literal["boolean", "integer", "text", "jid"] | None: ...

global___NodeAttrs = NodeAttrs

@typing.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    ATTRS_FIELD_NUMBER: builtins.int
    NODES_FIELD_NUMBER: builtins.int
    NIL_FIELD_NUMBER: builtins.int
    BYTES_FIELD_NUMBER: builtins.int
    Tag: builtins.str
    Nil: builtins.bool
    Bytes: builtins.bytes
    @property
    def Attrs(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___NodeAttrs
    ]: ...
    @property
    def Nodes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Node
    ]: ...
    def __init__(
        self,
        *,
        Tag: builtins.str | None = ...,
        Attrs: collections.abc.Iterable[global___NodeAttrs] | None = ...,
        Nodes: collections.abc.Iterable[global___Node] | None = ...,
        Nil: builtins.bool | None = ...,
        Bytes: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["Bytes", b"Bytes", "Nil", b"Nil", "Tag", b"Tag"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Attrs",
            b"Attrs",
            "Bytes",
            b"Bytes",
            "Nil",
            b"Nil",
            "Nodes",
            b"Nodes",
            "Tag",
            b"Tag",
        ],
    ) -> None: ...

global___Node = Node

@typing.final
class InfoQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    Namespace: builtins.str
    Type: builtins.str
    To: builtins.str
    @property
    def Content(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Node
    ]: ...
    def __init__(
        self,
        *,
        Namespace: builtins.str | None = ...,
        Type: builtins.str | None = ...,
        To: builtins.str | None = ...,
        Content: collections.abc.Iterable[global___Node] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Namespace", b"Namespace", "To", b"To", "Type", b"Type"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Content",
            b"Content",
            "Namespace",
            b"Namespace",
            "To",
            b"To",
            "Type",
            b"Type",
        ],
    ) -> None: ...

global___InfoQuery = InfoQuery

@typing.final
class GetProfilePictureParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREVIEW_FIELD_NUMBER: builtins.int
    EXISTINGID_FIELD_NUMBER: builtins.int
    ISCOMMUNITY_FIELD_NUMBER: builtins.int
    Preview: builtins.bool
    ExistingID: builtins.str
    IsCommunity: builtins.bool
    def __init__(
        self,
        *,
        Preview: builtins.bool | None = ...,
        ExistingID: builtins.str | None = ...,
        IsCommunity: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ExistingID",
            b"ExistingID",
            "IsCommunity",
            b"IsCommunity",
            "Preview",
            b"Preview",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ExistingID",
            b"ExistingID",
            "IsCommunity",
            b"IsCommunity",
            "Preview",
            b"Preview",
        ],
    ) -> None: ...

global___GetProfilePictureParams = GetProfilePictureParams

@typing.final
class GetProfilePictureReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PICTURE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Picture(self) -> global___ProfilePictureInfo: ...
    def __init__(
        self,
        *,
        Picture: global___ProfilePictureInfo | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "Picture", b"Picture"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "Picture", b"Picture"]
    ) -> None: ...

global___GetProfilePictureReturnFunction = GetProfilePictureReturnFunction

@typing.final
class StatusPrivacy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _StatusPrivacyType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusPrivacyTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            StatusPrivacy._StatusPrivacyType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONTACTS: StatusPrivacy._StatusPrivacyType.ValueType  # 1
        BLACKLIST: StatusPrivacy._StatusPrivacyType.ValueType  # 2
        WHITELIST: StatusPrivacy._StatusPrivacyType.ValueType  # 3

    class StatusPrivacyType(
        _StatusPrivacyType, metaclass=_StatusPrivacyTypeEnumTypeWrapper
    ): ...
    CONTACTS: StatusPrivacy.StatusPrivacyType.ValueType  # 1
    BLACKLIST: StatusPrivacy.StatusPrivacyType.ValueType  # 2
    WHITELIST: StatusPrivacy.StatusPrivacyType.ValueType  # 3

    TYPE_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    ISDEFAULT_FIELD_NUMBER: builtins.int
    Type: global___StatusPrivacy.StatusPrivacyType.ValueType
    IsDefault: builtins.bool
    @property
    def List(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        Type: global___StatusPrivacy.StatusPrivacyType.ValueType | None = ...,
        List: collections.abc.Iterable[global___JID] | None = ...,
        IsDefault: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["IsDefault", b"IsDefault", "Type", b"Type"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "IsDefault", b"IsDefault", "List", b"List", "Type", b"Type"
        ],
    ) -> None: ...

global___StatusPrivacy = StatusPrivacy

@typing.final
class GetStatusPrivacyReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUSPRIVACY_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def StatusPrivacy(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___StatusPrivacy
    ]: ...
    def __init__(
        self,
        *,
        StatusPrivacy: collections.abc.Iterable[global___StatusPrivacy] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "StatusPrivacy", b"StatusPrivacy"
        ],
    ) -> None: ...

global___GetStatusPrivacyReturnFunction = GetStatusPrivacyReturnFunction

@typing.final
class GroupLinkTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    GROUPNAME_FIELD_NUMBER: builtins.int
    GROUPISDEFAULTSUB_FIELD_NUMBER: builtins.int
    @property
    def JID(self) -> global___JID: ...
    @property
    def GroupName(self) -> global___GroupName: ...
    @property
    def GroupIsDefaultSub(self) -> global___GroupIsDefaultSub: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        GroupName: global___GroupName | None = ...,
        GroupIsDefaultSub: global___GroupIsDefaultSub | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "GroupIsDefaultSub",
            b"GroupIsDefaultSub",
            "GroupName",
            b"GroupName",
            "JID",
            b"JID",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "GroupIsDefaultSub",
            b"GroupIsDefaultSub",
            "GroupName",
            b"GroupName",
            "JID",
            b"JID",
        ],
    ) -> None: ...

global___GroupLinkTarget = GroupLinkTarget

@typing.final
class GroupLinkChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChangeType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChangeTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GroupLinkChange._ChangeType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PARENT: GroupLinkChange._ChangeType.ValueType  # 1
        SUB: GroupLinkChange._ChangeType.ValueType  # 2
        SIBLING: GroupLinkChange._ChangeType.ValueType  # 3

    class ChangeType(_ChangeType, metaclass=_ChangeTypeEnumTypeWrapper): ...
    PARENT: GroupLinkChange.ChangeType.ValueType  # 1
    SUB: GroupLinkChange.ChangeType.ValueType  # 2
    SIBLING: GroupLinkChange.ChangeType.ValueType  # 3

    TYPE_FIELD_NUMBER: builtins.int
    UNLINKREASON_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    Type: global___GroupLinkChange.ChangeType.ValueType
    UnlinkReason: builtins.str
    @property
    def Group(self) -> global___GroupLinkTarget: ...
    def __init__(
        self,
        *,
        Type: global___GroupLinkChange.ChangeType.ValueType | None = ...,
        UnlinkReason: builtins.str | None = ...,
        Group: global___GroupLinkTarget | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Group", b"Group", "Type", b"Type", "UnlinkReason", b"UnlinkReason"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Group", b"Group", "Type", b"Type", "UnlinkReason", b"UnlinkReason"
        ],
    ) -> None: ...

global___GroupLinkChange = GroupLinkChange

@typing.final
class GetSubGroupsReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPLINKTARGET_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def GroupLinkTarget(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GroupLinkTarget
    ]: ...
    def __init__(
        self,
        *,
        GroupLinkTarget: collections.abc.Iterable[global___GroupLinkTarget]
        | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "GroupLinkTarget", b"GroupLinkTarget"
        ],
    ) -> None: ...

global___GetSubGroupsReturnFunction = GetSubGroupsReturnFunction

@typing.final
class GetSubscribedNewslettersReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWSLETTER_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Newsletter(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___NewsletterMetadata
    ]: ...
    def __init__(
        self,
        *,
        Newsletter: collections.abc.Iterable[global___NewsletterMetadata] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "Newsletter", b"Newsletter"]
    ) -> None: ...

global___GetSubscribedNewslettersReturnFunction = GetSubscribedNewslettersReturnFunction

@typing.final
class GetUserDevicesreturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def JID(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    def __init__(
        self,
        *,
        JID: collections.abc.Iterable[global___JID] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "JID", b"JID"]
    ) -> None: ...

global___GetUserDevicesreturnFunction = GetUserDevicesreturnFunction

@typing.final
class NewsletterSubscribeLiveUpdatesReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Duration: builtins.int
    Error: builtins.str
    def __init__(
        self,
        *,
        Duration: builtins.int | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Duration", b"Duration", "Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Duration", b"Duration", "Error", b"Error"]
    ) -> None: ...

global___NewsletterSubscribeLiveUpdatesReturnFunction = (
    NewsletterSubscribeLiveUpdatesReturnFunction
)

@typing.final
class PairPhoneParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHONE_FIELD_NUMBER: builtins.int
    SHOWPUSHNOTIFICATION_FIELD_NUMBER: builtins.int
    CLIENTTYPE_FIELD_NUMBER: builtins.int
    CLIENTDISPLAYNAME_FIELD_NUMBER: builtins.int
    phone: builtins.str
    showPushNotification: builtins.bool
    clientType: builtins.int
    clientDisplayName: builtins.str
    def __init__(
        self,
        *,
        phone: builtins.str | None = ...,
        showPushNotification: builtins.bool | None = ...,
        clientType: builtins.int | None = ...,
        clientDisplayName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "clientDisplayName",
            b"clientDisplayName",
            "clientType",
            b"clientType",
            "phone",
            b"phone",
            "showPushNotification",
            b"showPushNotification",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "clientDisplayName",
            b"clientDisplayName",
            "clientType",
            b"clientType",
            "phone",
            b"phone",
            "showPushNotification",
            b"showPushNotification",
        ],
    ) -> None: ...

global___PairPhoneParams = PairPhoneParams

@typing.final
class ContactQRLinkTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    Type: builtins.str
    PushName: builtins.str
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Type: builtins.str | None = ...,
        PushName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "JID", b"JID", "PushName", b"PushName", "Type", b"Type"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "JID", b"JID", "PushName", b"PushName", "Type", b"Type"
        ],
    ) -> None: ...

global___ContactQRLinkTarget = ContactQRLinkTarget

@typing.final
class ResolveContactQRLinkReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTACTQRLINK_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def ContactQrLink(self) -> global___ContactQRLinkTarget: ...
    def __init__(
        self,
        *,
        ContactQrLink: global___ContactQRLinkTarget | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ContactQrLink", b"ContactQrLink", "Error", b"Error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ContactQrLink", b"ContactQrLink", "Error", b"Error"
        ],
    ) -> None: ...

global___ResolveContactQRLinkReturnFunction = ResolveContactQRLinkReturnFunction

@typing.final
class BusinessMessageLinkTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    VERIFIEDNAME_FIELD_NUMBER: builtins.int
    ISSIGNED_FIELD_NUMBER: builtins.int
    VERIFIEDLEVEL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PushName: builtins.str
    VerifiedName: builtins.str
    IsSigned: builtins.bool
    VerifiedLevel: builtins.str
    Message: builtins.str
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        PushName: builtins.str | None = ...,
        VerifiedName: builtins.str | None = ...,
        IsSigned: builtins.bool | None = ...,
        VerifiedLevel: builtins.str | None = ...,
        Message: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "IsSigned",
            b"IsSigned",
            "JID",
            b"JID",
            "Message",
            b"Message",
            "PushName",
            b"PushName",
            "VerifiedLevel",
            b"VerifiedLevel",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "IsSigned",
            b"IsSigned",
            "JID",
            b"JID",
            "Message",
            b"Message",
            "PushName",
            b"PushName",
            "VerifiedLevel",
            b"VerifiedLevel",
            "VerifiedName",
            b"VerifiedName",
        ],
    ) -> None: ...

global___BusinessMessageLinkTarget = BusinessMessageLinkTarget

@typing.final
class ResolveBusinessMessageLinkReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGELINKTARGET_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def MessageLinkTarget(self) -> global___BusinessMessageLinkTarget: ...
    def __init__(
        self,
        *,
        MessageLinkTarget: global___BusinessMessageLinkTarget | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "MessageLinkTarget", b"MessageLinkTarget"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "MessageLinkTarget", b"MessageLinkTarget"
        ],
    ) -> None: ...

global___ResolveBusinessMessageLinkReturnFunction = (
    ResolveBusinessMessageLinkReturnFunction
)

@typing.final
class MutationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    Version: builtins.int
    @property
    def Index(
        self,
    ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.str
    ]: ...
    @property
    def Value(self) -> waSyncAction.WASyncAction_pb2.SyncActionValue: ...
    def __init__(
        self,
        *,
        Index: collections.abc.Iterable[builtins.str] | None = ...,
        Version: builtins.int | None = ...,
        Value: waSyncAction.WASyncAction_pb2.SyncActionValue | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Value", b"Value", "Version", b"Version"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Index", b"Index", "Value", b"Value", "Version", b"Version"
        ],
    ) -> None: ...

global___MutationInfo = MutationInfo

@typing.final
class PatchInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WAPatchName:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WAPatchNameEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PatchInfo._WAPatchName.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CRITICAL_BLOCK: PatchInfo._WAPatchName.ValueType  # 1
        CRITICAL_UNBLOCK_LOW: PatchInfo._WAPatchName.ValueType  # 2
        REGULAR_LOW: PatchInfo._WAPatchName.ValueType  # 3
        REGULAR_HIGH: PatchInfo._WAPatchName.ValueType  # 4
        REGULAR: PatchInfo._WAPatchName.ValueType  # 5

    class WAPatchName(_WAPatchName, metaclass=_WAPatchNameEnumTypeWrapper): ...
    CRITICAL_BLOCK: PatchInfo.WAPatchName.ValueType  # 1
    CRITICAL_UNBLOCK_LOW: PatchInfo.WAPatchName.ValueType  # 2
    REGULAR_LOW: PatchInfo.WAPatchName.ValueType  # 3
    REGULAR_HIGH: PatchInfo.WAPatchName.ValueType  # 4
    REGULAR: PatchInfo.WAPatchName.ValueType  # 5

    TIMESTAMP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MUTATIONS_FIELD_NUMBER: builtins.int
    Timestamp: builtins.int
    Type: global___PatchInfo.WAPatchName.ValueType
    @property
    def Mutations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutationInfo
    ]: ...
    def __init__(
        self,
        *,
        Timestamp: builtins.int | None = ...,
        Type: global___PatchInfo.WAPatchName.ValueType | None = ...,
        Mutations: collections.abc.Iterable[global___MutationInfo] | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Timestamp", b"Timestamp", "Type", b"Type"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Mutations", b"Mutations", "Timestamp", b"Timestamp", "Type", b"Type"
        ],
    ) -> None: ...

global___PatchInfo = PatchInfo

@typing.final
class ContactsPutPushNameReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    PREVIOUSNAME_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Status: builtins.bool
    PreviousName: builtins.str
    Error: builtins.str
    def __init__(
        self,
        *,
        Status: builtins.bool | None = ...,
        PreviousName: builtins.str | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "PreviousName", b"PreviousName", "Status", b"Status"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error", b"Error", "PreviousName", b"PreviousName", "Status", b"Status"
        ],
    ) -> None: ...

global___ContactsPutPushNameReturnFunction = ContactsPutPushNameReturnFunction

@typing.final
class ContactEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    FIRSTNAME_FIELD_NUMBER: builtins.int
    FULLNAME_FIELD_NUMBER: builtins.int
    FirstName: builtins.str
    FullName: builtins.str
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        FirstName: builtins.str | None = ...,
        FullName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "FirstName", b"FirstName", "FullName", b"FullName", "JID", b"JID"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "FirstName", b"FirstName", "FullName", b"FullName", "JID", b"JID"
        ],
    ) -> None: ...

global___ContactEntry = ContactEntry

@typing.final
class ContactEntryArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTACTENTRY_FIELD_NUMBER: builtins.int
    @property
    def ContactEntry(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___ContactEntry
    ]: ...
    def __init__(
        self,
        *,
        ContactEntry: collections.abc.Iterable[global___ContactEntry] | None = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing.Literal["ContactEntry", b"ContactEntry"]
    ) -> None: ...

global___ContactEntryArray = ContactEntryArray

@typing.final
class SetPrivacySettingReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SETTINGS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def settings(self) -> global___PrivacySettings: ...
    def __init__(
        self,
        *,
        settings: global___PrivacySettings | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error", "settings", b"settings"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Error", b"Error", "settings", b"settings"]
    ) -> None: ...

global___SetPrivacySettingReturnFunction = SetPrivacySettingReturnFunction

@typing.final
class ContactsGetContactReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTACTINFO_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def ContactInfo(self) -> global___ContactInfo: ...
    def __init__(
        self,
        *,
        ContactInfo: global___ContactInfo | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["ContactInfo", b"ContactInfo", "Error", b"Error"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["ContactInfo", b"ContactInfo", "Error", b"Error"],
    ) -> None: ...

global___ContactsGetContactReturnFunction = ContactsGetContactReturnFunction

@typing.final
class ContactInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOUND_FIELD_NUMBER: builtins.int
    FIRSTNAME_FIELD_NUMBER: builtins.int
    FULLNAME_FIELD_NUMBER: builtins.int
    PUSHNAME_FIELD_NUMBER: builtins.int
    BUSINESSNAME_FIELD_NUMBER: builtins.int
    Found: builtins.bool
    FirstName: builtins.str
    FullName: builtins.str
    PushName: builtins.str
    BusinessName: builtins.str
    def __init__(
        self,
        *,
        Found: builtins.bool | None = ...,
        FirstName: builtins.str | None = ...,
        FullName: builtins.str | None = ...,
        PushName: builtins.str | None = ...,
        BusinessName: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "BusinessName",
            b"BusinessName",
            "FirstName",
            b"FirstName",
            "Found",
            b"Found",
            "FullName",
            b"FullName",
            "PushName",
            b"PushName",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "BusinessName",
            b"BusinessName",
            "FirstName",
            b"FirstName",
            "Found",
            b"Found",
            "FullName",
            b"FullName",
            "PushName",
            b"PushName",
        ],
    ) -> None: ...

global___ContactInfo = ContactInfo

@typing.final
class Contact(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    @property
    def JID(self) -> global___JID: ...
    @property
    def Info(self) -> global___ContactInfo: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Info: global___ContactInfo | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Info", b"Info", "JID", b"JID"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Info", b"Info", "JID", b"JID"]
    ) -> None: ...

global___Contact = Contact

@typing.final
class ContactsGetAllContactsReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTACT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def Contact(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Contact
    ]: ...
    def __init__(
        self,
        *,
        Contact: collections.abc.Iterable[global___Contact] | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Contact", b"Contact", "Error", b"Error"]
    ) -> None: ...

global___ContactsGetAllContactsReturnFunction = ContactsGetAllContactsReturnFunction

@typing.final
class QR(google.protobuf.message.Message):
    """events
    1
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODES_FIELD_NUMBER: builtins.int
    @property
    def Codes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.str
    ]: ...
    def __init__(
        self,
        *,
        Codes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["Codes", b"Codes"]) -> None: ...

global___QR = QR

@typing.final
class PairStatus(google.protobuf.message.Message):
    """2"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PStatusEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            PairStatus._PStatus.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ERROR: PairStatus._PStatus.ValueType  # 1
        SUCCESS: PairStatus._PStatus.ValueType  # 2

    class PStatus(_PStatus, metaclass=_PStatusEnumTypeWrapper): ...
    ERROR: PairStatus.PStatus.ValueType  # 1
    SUCCESS: PairStatus.PStatus.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    BUSINESSNAME_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    BusinessName: builtins.str
    Platform: builtins.str
    Status: global___PairStatus.PStatus.ValueType
    Error: builtins.str
    @property
    def ID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        ID: global___JID | None = ...,
        BusinessName: builtins.str | None = ...,
        Platform: builtins.str | None = ...,
        Status: global___PairStatus.PStatus.ValueType | None = ...,
        Error: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "BusinessName",
            b"BusinessName",
            "Error",
            b"Error",
            "ID",
            b"ID",
            "Platform",
            b"Platform",
            "Status",
            b"Status",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "BusinessName",
            b"BusinessName",
            "Error",
            b"Error",
            "ID",
            b"ID",
            "Platform",
            b"Platform",
            "Status",
            b"Status",
        ],
    ) -> None: ...

global___PairStatus = PairStatus

@typing.final
class Connected(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["status", b"status"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___Connected = Connected

@typing.final
class KeepAliveTimeout(google.protobuf.message.Message):
    """4"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERRORCOUNT_FIELD_NUMBER: builtins.int
    LASTSUCCESS_FIELD_NUMBER: builtins.int
    ErrorCount: builtins.int
    LastSuccess: builtins.int
    def __init__(
        self,
        *,
        ErrorCount: builtins.int | None = ...,
        LastSuccess: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ErrorCount", b"ErrorCount", "LastSuccess", b"LastSuccess"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ErrorCount", b"ErrorCount", "LastSuccess", b"LastSuccess"
        ],
    ) -> None: ...

global___KeepAliveTimeout = KeepAliveTimeout

@typing.final
class KeepAliveRestored(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___KeepAliveRestored = KeepAliveRestored

@typing.final
class LoggedOut(google.protobuf.message.Message):
    """6"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONCONNECT_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    OnConnect: builtins.bool
    Reason: global___ConnectFailureReason.ValueType
    def __init__(
        self,
        *,
        OnConnect: builtins.bool | None = ...,
        Reason: global___ConnectFailureReason.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["OnConnect", b"OnConnect", "Reason", b"Reason"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["OnConnect", b"OnConnect", "Reason", b"Reason"]
    ) -> None: ...

global___LoggedOut = LoggedOut

@typing.final
class StreamReplaced(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___StreamReplaced = StreamReplaced

@typing.final
class TemporaryBan(google.protobuf.message.Message):
    """8"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _TempBanReason:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TempBanReasonEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TemporaryBan._TempBanReason.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SEND_TO_TOO_MANY_PEOPLE: TemporaryBan._TempBanReason.ValueType  # 1
        BLOCKED_BY_USERS: TemporaryBan._TempBanReason.ValueType  # 2
        CREATED_TOO_MANY_GROUPS: TemporaryBan._TempBanReason.ValueType  # 3
        SENT_TOO_MANY_SAME_MESSAGE: TemporaryBan._TempBanReason.ValueType  # 4
        BROADCAST_LIST: TemporaryBan._TempBanReason.ValueType  # 5

    class TempBanReason(_TempBanReason, metaclass=_TempBanReasonEnumTypeWrapper): ...
    SEND_TO_TOO_MANY_PEOPLE: TemporaryBan.TempBanReason.ValueType  # 1
    BLOCKED_BY_USERS: TemporaryBan.TempBanReason.ValueType  # 2
    CREATED_TOO_MANY_GROUPS: TemporaryBan.TempBanReason.ValueType  # 3
    SENT_TOO_MANY_SAME_MESSAGE: TemporaryBan.TempBanReason.ValueType  # 4
    BROADCAST_LIST: TemporaryBan.TempBanReason.ValueType  # 5

    CODE_FIELD_NUMBER: builtins.int
    EXPIRE_FIELD_NUMBER: builtins.int
    Code: global___TemporaryBan.TempBanReason.ValueType
    Expire: builtins.int
    def __init__(
        self,
        *,
        Code: global___TemporaryBan.TempBanReason.ValueType | None = ...,
        Expire: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Code", b"Code", "Expire", b"Expire"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Code", b"Code", "Expire", b"Expire"]
    ) -> None: ...

global___TemporaryBan = TemporaryBan

@typing.final
class ConnectFailure(google.protobuf.message.Message):
    """9"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    RAW_FIELD_NUMBER: builtins.int
    Reason: global___ConnectFailureReason.ValueType
    Message: builtins.str
    @property
    def Raw(self) -> global___Node: ...
    def __init__(
        self,
        *,
        Reason: global___ConnectFailureReason.ValueType | None = ...,
        Message: builtins.str | None = ...,
        Raw: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Message", b"Message", "Raw", b"Raw", "Reason", b"Reason"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Message", b"Message", "Raw", b"Raw", "Reason", b"Reason"
        ],
    ) -> None: ...

global___ConnectFailure = ConnectFailure

@typing.final
class ClientOutdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ClientOutdated = ClientOutdated

@typing.final
class StreamError(google.protobuf.message.Message):
    """11"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    RAW_FIELD_NUMBER: builtins.int
    Code: builtins.str
    @property
    def Raw(self) -> global___Node: ...
    def __init__(
        self,
        *,
        Code: builtins.str | None = ...,
        Raw: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Code", b"Code", "Raw", b"Raw"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Code", b"Code", "Raw", b"Raw"]
    ) -> None: ...

global___StreamError = StreamError

@typing.final
class Disconnected(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.bool
    def __init__(
        self,
        *,
        status: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["status", b"status"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___Disconnected = Disconnected

@typing.final
class HistorySync(google.protobuf.message.Message):
    """13"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def Data(self) -> waHistorySync.WAWebProtobufsHistorySync_pb2.HistorySync: ...
    def __init__(
        self,
        *,
        Data: waHistorySync.WAWebProtobufsHistorySync_pb2.HistorySync | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Data", b"Data"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Data", b"Data"]) -> None: ...

global___HistorySync = HistorySync

@typing.final
class Receipt(google.protobuf.message.Message):
    """message DecryptFailMode // 14
    message UndecryptableMessage // 15
    message NewsLetterMessageMeta (Defined) // 16
    Message (Defined) // 17
    18
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ReceiptType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReceiptTypeEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            Receipt._ReceiptType.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DELIVERED: Receipt._ReceiptType.ValueType  # 1
        SENDER: Receipt._ReceiptType.ValueType  # 2
        RETRY: Receipt._ReceiptType.ValueType  # 3
        READ: Receipt._ReceiptType.ValueType  # 4
        READ_SELF: Receipt._ReceiptType.ValueType  # 5
        PLAYED: Receipt._ReceiptType.ValueType  # 6
        PLAYED_SELF: Receipt._ReceiptType.ValueType  # 7
        SERVER_ERROR: Receipt._ReceiptType.ValueType  # 8
        INACTIVE: Receipt._ReceiptType.ValueType  # 9
        PEER_MSG: Receipt._ReceiptType.ValueType  # 10
        HISTORY_SYNC: Receipt._ReceiptType.ValueType  # 11

    class ReceiptType(_ReceiptType, metaclass=_ReceiptTypeEnumTypeWrapper): ...
    DELIVERED: Receipt.ReceiptType.ValueType  # 1
    SENDER: Receipt.ReceiptType.ValueType  # 2
    RETRY: Receipt.ReceiptType.ValueType  # 3
    READ: Receipt.ReceiptType.ValueType  # 4
    READ_SELF: Receipt.ReceiptType.ValueType  # 5
    PLAYED: Receipt.ReceiptType.ValueType  # 6
    PLAYED_SELF: Receipt.ReceiptType.ValueType  # 7
    SERVER_ERROR: Receipt.ReceiptType.ValueType  # 8
    INACTIVE: Receipt.ReceiptType.ValueType  # 9
    PEER_MSG: Receipt.ReceiptType.ValueType  # 10
    HISTORY_SYNC: Receipt.ReceiptType.ValueType  # 11

    MESSAGESOURCE_FIELD_NUMBER: builtins.int
    MESSAGEIDS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    Timestamp: builtins.int
    Type: global___Receipt.ReceiptType.ValueType
    @property
    def MessageSource(self) -> global___MessageSource: ...
    @property
    def MessageIDs(
        self,
    ) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        builtins.str
    ]: ...
    def __init__(
        self,
        *,
        MessageSource: global___MessageSource | None = ...,
        MessageIDs: collections.abc.Iterable[builtins.str] | None = ...,
        Timestamp: builtins.int | None = ...,
        Type: global___Receipt.ReceiptType.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "MessageSource",
            b"MessageSource",
            "Timestamp",
            b"Timestamp",
            "Type",
            b"Type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "MessageIDs",
            b"MessageIDs",
            "MessageSource",
            b"MessageSource",
            "Timestamp",
            b"Timestamp",
            "Type",
            b"Type",
        ],
    ) -> None: ...

global___Receipt = Receipt

@typing.final
class ChatPresence(google.protobuf.message.Message):
    """19"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChatPresence:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChatPresenceEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChatPresence._ChatPresence.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        COMPOSING: ChatPresence._ChatPresence.ValueType  # 1
        PAUSED: ChatPresence._ChatPresence.ValueType  # 2

    class ChatPresence(_ChatPresence, metaclass=_ChatPresenceEnumTypeWrapper): ...
    COMPOSING: ChatPresence.ChatPresence.ValueType  # 1
    PAUSED: ChatPresence.ChatPresence.ValueType  # 2

    class _ChatPresenceMedia:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChatPresenceMediaEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChatPresence._ChatPresenceMedia.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TEXT: ChatPresence._ChatPresenceMedia.ValueType  # 1
        AUDIO: ChatPresence._ChatPresenceMedia.ValueType  # 2

    class ChatPresenceMedia(
        _ChatPresenceMedia, metaclass=_ChatPresenceMediaEnumTypeWrapper
    ): ...
    TEXT: ChatPresence.ChatPresenceMedia.ValueType  # 1
    AUDIO: ChatPresence.ChatPresenceMedia.ValueType  # 2

    MESSAGESOURCE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    MEDIA_FIELD_NUMBER: builtins.int
    State: global___ChatPresence.ChatPresence.ValueType
    Media: global___ChatPresence.ChatPresenceMedia.ValueType
    @property
    def MessageSource(self) -> global___MessageSource: ...
    def __init__(
        self,
        *,
        MessageSource: global___MessageSource | None = ...,
        State: global___ChatPresence.ChatPresence.ValueType | None = ...,
        Media: global___ChatPresence.ChatPresenceMedia.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Media", b"Media", "MessageSource", b"MessageSource", "State", b"State"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Media", b"Media", "MessageSource", b"MessageSource", "State", b"State"
        ],
    ) -> None: ...

global___ChatPresence = ChatPresence

@typing.final
class Presence(google.protobuf.message.Message):
    """20"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    UNAVAILABLE_FIELD_NUMBER: builtins.int
    LASTSEEN_FIELD_NUMBER: builtins.int
    Unavailable: builtins.bool
    LastSeen: builtins.int
    @property
    def From(self) -> global___JID: ...
    def __init__(
        self,
        *,
        From: global___JID | None = ...,
        Unavailable: builtins.bool | None = ...,
        LastSeen: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "From", b"From", "LastSeen", b"LastSeen", "Unavailable", b"Unavailable"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "From", b"From", "LastSeen", b"LastSeen", "Unavailable", b"Unavailable"
        ],
    ) -> None: ...

global___Presence = Presence

@typing.final
class JoinedGroup(google.protobuf.message.Message):
    """21"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATEKEY_FIELD_NUMBER: builtins.int
    GROUPINFO_FIELD_NUMBER: builtins.int
    Reason: builtins.str
    Type: builtins.str
    CreateKey: builtins.str
    @property
    def GroupInfo(self) -> global___GroupInfo: ...
    def __init__(
        self,
        *,
        Reason: builtins.str | None = ...,
        Type: builtins.str | None = ...,
        CreateKey: builtins.str | None = ...,
        GroupInfo: global___GroupInfo | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "CreateKey",
            b"CreateKey",
            "GroupInfo",
            b"GroupInfo",
            "Reason",
            b"Reason",
            "Type",
            b"Type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "CreateKey",
            b"CreateKey",
            "GroupInfo",
            b"GroupInfo",
            "Reason",
            b"Reason",
            "Type",
            b"Type",
        ],
    ) -> None: ...

global___JoinedGroup = JoinedGroup

@typing.final
class GroupInfoEvent(google.protobuf.message.Message):
    """22"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    NOTIFY_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    LOCKED_FIELD_NUMBER: builtins.int
    ANNOUNCE_FIELD_NUMBER: builtins.int
    EPHEMERAL_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    UNLINK_FIELD_NUMBER: builtins.int
    NEWINVITELINK_FIELD_NUMBER: builtins.int
    PREVPARTICIPANTSVERSIONID_FIELD_NUMBER: builtins.int
    PARTICIPANTVERSIONID_FIELD_NUMBER: builtins.int
    JOINREASON_FIELD_NUMBER: builtins.int
    JOIN_FIELD_NUMBER: builtins.int
    LEAVE_FIELD_NUMBER: builtins.int
    PROMOTE_FIELD_NUMBER: builtins.int
    DEMOTE_FIELD_NUMBER: builtins.int
    UNKNOWNCHANGES_FIELD_NUMBER: builtins.int
    Notify: builtins.str
    Timestamp: builtins.int
    NewInviteLink: builtins.str
    PrevParticipantsVersionID: builtins.str
    ParticipantVersionID: builtins.str
    JoinReason: builtins.str
    @property
    def JID(self) -> global___JID: ...
    @property
    def Sender(self) -> global___JID: ...
    @property
    def Name(self) -> global___GroupName: ...
    @property
    def Topic(self) -> global___GroupTopic: ...
    @property
    def Locked(self) -> global___GroupLocked: ...
    @property
    def Announce(self) -> global___GroupAnnounce: ...
    @property
    def Ephemeral(self) -> global___GroupEphemeral: ...
    @property
    def Delete(self) -> global___GroupDelete: ...
    @property
    def Link(self) -> global___GroupLinkChange: ...
    @property
    def Unlink(self) -> global___GroupLinkChange: ...
    @property
    def Join(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    @property
    def Leave(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    @property
    def Promote(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    @property
    def Demote(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___JID
    ]: ...
    @property
    def UnknownChanges(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Node
    ]: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Notify: builtins.str | None = ...,
        Sender: global___JID | None = ...,
        Timestamp: builtins.int | None = ...,
        Name: global___GroupName | None = ...,
        Topic: global___GroupTopic | None = ...,
        Locked: global___GroupLocked | None = ...,
        Announce: global___GroupAnnounce | None = ...,
        Ephemeral: global___GroupEphemeral | None = ...,
        Delete: global___GroupDelete | None = ...,
        Link: global___GroupLinkChange | None = ...,
        Unlink: global___GroupLinkChange | None = ...,
        NewInviteLink: builtins.str | None = ...,
        PrevParticipantsVersionID: builtins.str | None = ...,
        ParticipantVersionID: builtins.str | None = ...,
        JoinReason: builtins.str | None = ...,
        Join: collections.abc.Iterable[global___JID] | None = ...,
        Leave: collections.abc.Iterable[global___JID] | None = ...,
        Promote: collections.abc.Iterable[global___JID] | None = ...,
        Demote: collections.abc.Iterable[global___JID] | None = ...,
        UnknownChanges: collections.abc.Iterable[global___Node] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Announce",
            b"Announce",
            "Delete",
            b"Delete",
            "Ephemeral",
            b"Ephemeral",
            "JID",
            b"JID",
            "JoinReason",
            b"JoinReason",
            "Link",
            b"Link",
            "Locked",
            b"Locked",
            "Name",
            b"Name",
            "NewInviteLink",
            b"NewInviteLink",
            "Notify",
            b"Notify",
            "ParticipantVersionID",
            b"ParticipantVersionID",
            "PrevParticipantsVersionID",
            b"PrevParticipantsVersionID",
            "Sender",
            b"Sender",
            "Timestamp",
            b"Timestamp",
            "Topic",
            b"Topic",
            "Unlink",
            b"Unlink",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Announce",
            b"Announce",
            "Delete",
            b"Delete",
            "Demote",
            b"Demote",
            "Ephemeral",
            b"Ephemeral",
            "JID",
            b"JID",
            "Join",
            b"Join",
            "JoinReason",
            b"JoinReason",
            "Leave",
            b"Leave",
            "Link",
            b"Link",
            "Locked",
            b"Locked",
            "Name",
            b"Name",
            "NewInviteLink",
            b"NewInviteLink",
            "Notify",
            b"Notify",
            "ParticipantVersionID",
            b"ParticipantVersionID",
            "PrevParticipantsVersionID",
            b"PrevParticipantsVersionID",
            "Promote",
            b"Promote",
            "Sender",
            b"Sender",
            "Timestamp",
            b"Timestamp",
            "Topic",
            b"Topic",
            "UnknownChanges",
            b"UnknownChanges",
            "Unlink",
            b"Unlink",
        ],
    ) -> None: ...

global___GroupInfoEvent = GroupInfoEvent

@typing.final
class Picture(google.protobuf.message.Message):
    """23"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    Timestamp: builtins.int
    Remove: builtins.bool
    @property
    def JID(self) -> global___JID: ...
    @property
    def Author(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Author: global___JID | None = ...,
        Timestamp: builtins.int | None = ...,
        Remove: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Author",
            b"Author",
            "JID",
            b"JID",
            "Remove",
            b"Remove",
            "Timestamp",
            b"Timestamp",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Author",
            b"Author",
            "JID",
            b"JID",
            "Remove",
            b"Remove",
            "Timestamp",
            b"Timestamp",
        ],
    ) -> None: ...

global___Picture = Picture

@typing.final
class IdentityChange(google.protobuf.message.Message):
    """24"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    IMPLICIT_FIELD_NUMBER: builtins.int
    Timestamp: builtins.int
    Implicit: builtins.bool
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        Timestamp: builtins.int | None = ...,
        Implicit: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Implicit", b"Implicit", "JID", b"JID", "Timestamp", b"Timestamp"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Implicit", b"Implicit", "JID", b"JID", "Timestamp", b"Timestamp"
        ],
    ) -> None: ...

global___IdentityChange = IdentityChange

@typing.final
class privacySettingsEvent(google.protobuf.message.Message):
    """25"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWSETTINGS_FIELD_NUMBER: builtins.int
    GROUPADDCHANGED_FIELD_NUMBER: builtins.int
    LASTSEENCHANGED_FIELD_NUMBER: builtins.int
    STATUSCHANGED_FIELD_NUMBER: builtins.int
    PROFILECHANGED_FIELD_NUMBER: builtins.int
    READRECEIPTSCHANGED_FIELD_NUMBER: builtins.int
    ONLINECHANGED_FIELD_NUMBER: builtins.int
    CALLADDCHANGED_FIELD_NUMBER: builtins.int
    GroupAddChanged: builtins.bool
    LastSeenChanged: builtins.bool
    StatusChanged: builtins.bool
    ProfileChanged: builtins.bool
    ReadReceiptsChanged: builtins.bool
    OnlineChanged: builtins.bool
    CallAddChanged: builtins.bool
    @property
    def NewSettings(self) -> global___PrivacySettings: ...
    def __init__(
        self,
        *,
        NewSettings: global___PrivacySettings | None = ...,
        GroupAddChanged: builtins.bool | None = ...,
        LastSeenChanged: builtins.bool | None = ...,
        StatusChanged: builtins.bool | None = ...,
        ProfileChanged: builtins.bool | None = ...,
        ReadReceiptsChanged: builtins.bool | None = ...,
        OnlineChanged: builtins.bool | None = ...,
        CallAddChanged: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "CallAddChanged",
            b"CallAddChanged",
            "GroupAddChanged",
            b"GroupAddChanged",
            "LastSeenChanged",
            b"LastSeenChanged",
            "NewSettings",
            b"NewSettings",
            "OnlineChanged",
            b"OnlineChanged",
            "ProfileChanged",
            b"ProfileChanged",
            "ReadReceiptsChanged",
            b"ReadReceiptsChanged",
            "StatusChanged",
            b"StatusChanged",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "CallAddChanged",
            b"CallAddChanged",
            "GroupAddChanged",
            b"GroupAddChanged",
            "LastSeenChanged",
            b"LastSeenChanged",
            "NewSettings",
            b"NewSettings",
            "OnlineChanged",
            b"OnlineChanged",
            "ProfileChanged",
            b"ProfileChanged",
            "ReadReceiptsChanged",
            b"ReadReceiptsChanged",
            "StatusChanged",
            b"StatusChanged",
        ],
    ) -> None: ...

global___privacySettingsEvent = privacySettingsEvent

@typing.final
class OfflineSyncPreview(google.protobuf.message.Message):
    """26"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    APPDATACHANGES_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    RECEIPTS_FIELD_NUMBER: builtins.int
    Total: builtins.int
    AppDataChanges: builtins.int
    Message: builtins.int
    Notifications: builtins.int
    Receipts: builtins.int
    def __init__(
        self,
        *,
        Total: builtins.int | None = ...,
        AppDataChanges: builtins.int | None = ...,
        Message: builtins.int | None = ...,
        Notifications: builtins.int | None = ...,
        Receipts: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "AppDataChanges",
            b"AppDataChanges",
            "Message",
            b"Message",
            "Notifications",
            b"Notifications",
            "Receipts",
            b"Receipts",
            "Total",
            b"Total",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "AppDataChanges",
            b"AppDataChanges",
            "Message",
            b"Message",
            "Notifications",
            b"Notifications",
            "Receipts",
            b"Receipts",
            "Total",
            b"Total",
        ],
    ) -> None: ...

global___OfflineSyncPreview = OfflineSyncPreview

@typing.final
class OfflineSyncCompleted(google.protobuf.message.Message):
    """27"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    Count: builtins.int
    def __init__(
        self,
        *,
        Count: builtins.int | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Count", b"Count"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Count", b"Count"]) -> None: ...

global___OfflineSyncCompleted = OfflineSyncCompleted

@typing.final
class BlocklistEvent(google.protobuf.message.Message):
    """30"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Actions:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionsEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BlocklistEvent._Actions.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT: BlocklistEvent._Actions.ValueType  # 1
        MODIFY: BlocklistEvent._Actions.ValueType  # 2

    class Actions(_Actions, metaclass=_ActionsEnumTypeWrapper): ...
    DEFAULT: BlocklistEvent.Actions.ValueType  # 1
    MODIFY: BlocklistEvent.Actions.ValueType  # 2

    ACTION_FIELD_NUMBER: builtins.int
    DHASH_FIELD_NUMBER: builtins.int
    PREVDHASH_FIELD_NUMBER: builtins.int
    CHANGES_FIELD_NUMBER: builtins.int
    Action: global___BlocklistEvent.Actions.ValueType
    DHASH: builtins.str
    PrevDHash: builtins.str
    @property
    def Changes(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BlocklistChange
    ]: ...
    def __init__(
        self,
        *,
        Action: global___BlocklistEvent.Actions.ValueType | None = ...,
        DHASH: builtins.str | None = ...,
        PrevDHash: builtins.str | None = ...,
        Changes: collections.abc.Iterable[global___BlocklistChange] | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Action", b"Action", "DHASH", b"DHASH", "PrevDHash", b"PrevDHash"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Action",
            b"Action",
            "Changes",
            b"Changes",
            "DHASH",
            b"DHASH",
            "PrevDHash",
            b"PrevDHash",
        ],
    ) -> None: ...

global___BlocklistEvent = BlocklistEvent

@typing.final
class BlocklistChange(google.protobuf.message.Message):
    """31"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            BlocklistChange._Action.ValueType
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        BLOCK: BlocklistChange._Action.ValueType  # 1
        UNBLOCK: BlocklistChange._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    BLOCK: BlocklistChange.Action.ValueType  # 1
    UNBLOCK: BlocklistChange.Action.ValueType  # 2

    JID_FIELD_NUMBER: builtins.int
    BLOCKACTION_FIELD_NUMBER: builtins.int
    BlockAction: global___BlocklistChange.Action.ValueType
    @property
    def JID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        BlockAction: global___BlocklistChange.Action.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["BlockAction", b"BlockAction", "JID", b"JID"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["BlockAction", b"BlockAction", "JID", b"JID"]
    ) -> None: ...

global___BlocklistChange = BlocklistChange

@typing.final
class NewsletterJoin(google.protobuf.message.Message):
    """32"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWSLETTERMETADATA_FIELD_NUMBER: builtins.int
    @property
    def NewsletterMetadata(self) -> global___NewsletterMetadata: ...
    def __init__(
        self,
        *,
        NewsletterMetadata: global___NewsletterMetadata | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["NewsletterMetadata", b"NewsletterMetadata"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["NewsletterMetadata", b"NewsletterMetadata"]
    ) -> None: ...

global___NewsletterJoin = NewsletterJoin

@typing.final
class NewsletterLeave(google.protobuf.message.Message):
    """33"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    Role: global___NewsletterRole.ValueType
    @property
    def ID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        ID: global___JID | None = ...,
        Role: global___NewsletterRole.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["ID", b"ID", "Role", b"Role"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["ID", b"ID", "Role", b"Role"]
    ) -> None: ...

global___NewsletterLeave = NewsletterLeave

@typing.final
class NewsletterMuteChange(google.protobuf.message.Message):
    """34"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MUTE_FIELD_NUMBER: builtins.int
    Mute: global___NewsletterMuteState.ValueType
    @property
    def ID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        ID: global___JID | None = ...,
        Mute: global___NewsletterMuteState.ValueType | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["ID", b"ID", "Mute", b"Mute"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["ID", b"ID", "Mute", b"Mute"]
    ) -> None: ...

global___NewsletterMuteChange = NewsletterMuteChange

@typing.final
class NewsletterLiveUpdate(google.protobuf.message.Message):
    """35"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    TIME: builtins.int
    @property
    def JID(self) -> global___JID: ...
    @property
    def Messages(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___NewsletterMessage
    ]: ...
    def __init__(
        self,
        *,
        JID: global___JID | None = ...,
        TIME: builtins.int | None = ...,
        Messages: collections.abc.Iterable[global___NewsletterMessage] | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["JID", b"JID", "TIME", b"TIME"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "JID", b"JID", "Messages", b"Messages", "TIME", b"TIME"
        ],
    ) -> None: ...

global___NewsletterLiveUpdate = NewsletterLiveUpdate

@typing.final
class BasicCallMeta(google.protobuf.message.Message):
    """call events"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CALLCREATOR_FIELD_NUMBER: builtins.int
    CALLID_FIELD_NUMBER: builtins.int
    timestamp: builtins.int
    callID: builtins.str
    @property
    def callCreator(self) -> global___JID: ...
    def __init__(
        self,
        *,
        timestamp: builtins.int | None = ...,
        callCreator: global___JID | None = ...,
        callID: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "callCreator",
            b"callCreator",
            "callID",
            b"callID",
            "from",
            b"from",
            "timestamp",
            b"timestamp",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "callCreator",
            b"callCreator",
            "callID",
            b"callID",
            "from",
            b"from",
            "timestamp",
            b"timestamp",
        ],
    ) -> None: ...

global___BasicCallMeta = BasicCallMeta

@typing.final
class CallRemoteMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMOTEPLATFORM_FIELD_NUMBER: builtins.int
    REMOTEVERSION_FIELD_NUMBER: builtins.int
    remotePlatform: builtins.str
    remoteVersion: builtins.str
    def __init__(
        self,
        *,
        remotePlatform: builtins.str | None = ...,
        remoteVersion: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "remotePlatform", b"remotePlatform", "remoteVersion", b"remoteVersion"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "remotePlatform", b"remotePlatform", "remoteVersion", b"remoteVersion"
        ],
    ) -> None: ...

global___CallRemoteMeta = CallRemoteMeta

@typing.final
class CallOffer(google.protobuf.message.Message):
    """events"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    CALLREMOTEMETA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def callRemoteMeta(self) -> global___CallRemoteMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        callRemoteMeta: global___CallRemoteMeta | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> None: ...

global___CallOffer = CallOffer

@typing.final
class CallAccept(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    CALLREMOTEMETA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def callRemoteMeta(self) -> global___CallRemoteMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        callRemoteMeta: global___CallRemoteMeta | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> None: ...

global___CallAccept = CallAccept

@typing.final
class CallPreAccept(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    CALLREMOTEMETA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def callRemoteMeta(self) -> global___CallRemoteMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        callRemoteMeta: global___CallRemoteMeta | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> None: ...

global___CallPreAccept = CallPreAccept

@typing.final
class CallTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    CALLREMOTEMETA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def callRemoteMeta(self) -> global___CallRemoteMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        callRemoteMeta: global___CallRemoteMeta | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "callRemoteMeta",
            b"callRemoteMeta",
            "data",
            b"data",
        ],
    ) -> None: ...

global___CallTransport = CallTransport

@typing.final
class CallOfferNotice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    MEDIA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    media: builtins.str
    type: builtins.str
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        media: builtins.str | None = ...,
        type: builtins.str | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "data",
            b"data",
            "media",
            b"media",
            "type",
            b"type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta",
            b"basicCallMeta",
            "data",
            b"data",
            "media",
            b"media",
            "type",
            b"type",
        ],
    ) -> None: ...

global___CallOfferNotice = CallOfferNotice

@typing.final
class CallRelayLatency(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal["basicCallMeta", b"basicCallMeta", "data", b"data"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["basicCallMeta", b"basicCallMeta", "data", b"data"],
    ) -> None: ...

global___CallRelayLatency = CallRelayLatency

@typing.final
class CallTerminate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASICCALLMETA_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    reason: builtins.str
    @property
    def basicCallMeta(self) -> global___BasicCallMeta: ...
    @property
    def data(self) -> global___Node: ...
    def __init__(
        self,
        *,
        basicCallMeta: global___BasicCallMeta | None = ...,
        reason: builtins.str | None = ...,
        data: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "basicCallMeta", b"basicCallMeta", "data", b"data", "reason", b"reason"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "basicCallMeta", b"basicCallMeta", "data", b"data", "reason", b"reason"
        ],
    ) -> None: ...

global___CallTerminate = CallTerminate

@typing.final
class UnknownCallEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_FIELD_NUMBER: builtins.int
    @property
    def node(self) -> global___Node: ...
    def __init__(
        self,
        *,
        node: global___Node | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["node", b"node"]
    ) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["node", b"node"]) -> None: ...

global___UnknownCallEvent = UnknownCallEvent

@typing.final
class UpdateGroupParticipantsReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    PARTICIPANTS_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def participants(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GroupParticipant
    ]: ...
    def __init__(
        self,
        *,
        Error: builtins.str | None = ...,
        participants: collections.abc.Iterable[global___GroupParticipant] | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Error", b"Error"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal["Error", b"Error", "participants", b"participants"],
    ) -> None: ...

global___UpdateGroupParticipantsReturnFunction = UpdateGroupParticipantsReturnFunction

@typing.final
class GetMessageForRetryReturnFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISEMPTY_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    isEmpty: builtins.bool
    @property
    def Message(self) -> waE2E.WAWebProtobufsE2E_pb2.Message: ...
    def __init__(
        self,
        *,
        isEmpty: builtins.bool | None = ...,
        Message: waE2E.WAWebProtobufsE2E_pb2.Message | None = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing.Literal["Message", b"Message", "isEmpty", b"isEmpty"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing.Literal["Message", b"Message", "isEmpty", b"isEmpty"]
    ) -> None: ...

global___GetMessageForRetryReturnFunction = GetMessageForRetryReturnFunction

@typing.final
class LocalChatSettings(google.protobuf.message.Message):
    """chat_setting_store"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOUND_FIELD_NUMBER: builtins.int
    MUTEDUNTIL_FIELD_NUMBER: builtins.int
    PINNED_FIELD_NUMBER: builtins.int
    ARCHIVED_FIELD_NUMBER: builtins.int
    Found: builtins.bool
    MutedUntil: builtins.float
    Pinned: builtins.bool
    Archived: builtins.bool
    def __init__(
        self,
        *,
        Found: builtins.bool | None = ...,
        MutedUntil: builtins.float | None = ...,
        Pinned: builtins.bool | None = ...,
        Archived: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Archived",
            b"Archived",
            "Found",
            b"Found",
            "MutedUntil",
            b"MutedUntil",
            "Pinned",
            b"Pinned",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Archived",
            b"Archived",
            "Found",
            b"Found",
            "MutedUntil",
            b"MutedUntil",
            "Pinned",
            b"Pinned",
        ],
    ) -> None: ...

global___LocalChatSettings = LocalChatSettings

@typing.final
class ReturnFunctionWithError(google.protobuf.message.Message):
    """New Verision for Function"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    LOCALCHATSETTINGS_FIELD_NUMBER: builtins.int
    Error: builtins.str
    @property
    def LocalChatSettings(self) -> global___LocalChatSettings: ...
    def __init__(
        self,
        *,
        Error: builtins.str | None = ...,
        LocalChatSettings: global___LocalChatSettings | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "Error",
            b"Error",
            "LocalChatSettings",
            b"LocalChatSettings",
            "Return",
            b"Return",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "Error",
            b"Error",
            "LocalChatSettings",
            b"LocalChatSettings",
            "Return",
            b"Return",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing.Literal["Return", b"Return"]
    ) -> typing.Literal["LocalChatSettings"] | None: ...

global___ReturnFunctionWithError = ReturnFunctionWithError

@typing.final
class SendRequestExtra(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INLINEBOTJID_FIELD_NUMBER: builtins.int
    PEER_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    MEDIAHANDLE_FIELD_NUMBER: builtins.int
    ID: builtins.str
    Peer: builtins.bool
    Timeout: builtins.int
    MediaHandle: builtins.str
    @property
    def InlineBotJID(self) -> global___JID: ...
    def __init__(
        self,
        *,
        ID: builtins.str | None = ...,
        InlineBotJID: global___JID | None = ...,
        Peer: builtins.bool | None = ...,
        Timeout: builtins.int | None = ...,
        MediaHandle: builtins.str | None = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing.Literal[
            "ID",
            b"ID",
            "InlineBotJID",
            b"InlineBotJID",
            "MediaHandle",
            b"MediaHandle",
            "Peer",
            b"Peer",
            "Timeout",
            b"Timeout",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing.Literal[
            "ID",
            b"ID",
            "InlineBotJID",
            b"InlineBotJID",
            "MediaHandle",
            b"MediaHandle",
            "Peer",
            b"Peer",
            "Timeout",
            b"Timeout",
        ],
    ) -> None: ...

global___SendRequestExtra = SendRequestExtra
